"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import app.app.v1alpha.conversation_pb2
import builtins
import collections.abc
import common.healthcheck.v1beta.healthcheck_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _AppType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _AppTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_AppType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    APP_TYPE_UNSPECIFIED: _AppType.ValueType  # 0
    """AppType is not specified."""
    APP_TYPE_AI_ASSISTANT: _AppType.ValueType  # 1
    """AppType is a AI assistant app."""

class AppType(_AppType, metaclass=_AppTypeEnumTypeWrapper):
    """AppType represents the type of the app."""

APP_TYPE_UNSPECIFIED: AppType.ValueType  # 0
"""AppType is not specified."""
APP_TYPE_AI_ASSISTANT: AppType.ValueType  # 1
"""AppType is a AI assistant app."""
global___AppType = AppType

@typing_extensions.final
class LivenessRequest(google.protobuf.message.Message):
    """LivenessRequest represents a request to check a service liveness status"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEALTH_CHECK_REQUEST_FIELD_NUMBER: builtins.int
    @property
    def health_check_request(self) -> common.healthcheck.v1beta.healthcheck_pb2.HealthCheckRequest:
        """HealthCheckRequest message"""
    def __init__(
        self,
        *,
        health_check_request: common.healthcheck.v1beta.healthcheck_pb2.HealthCheckRequest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_health_check_request", b"_health_check_request", "health_check_request", b"health_check_request"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_health_check_request", b"_health_check_request", "health_check_request", b"health_check_request"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_health_check_request", b"_health_check_request"]) -> typing_extensions.Literal["health_check_request"] | None: ...

global___LivenessRequest = LivenessRequest

@typing_extensions.final
class LivenessResponse(google.protobuf.message.Message):
    """LivenessResponse represents a response for a service liveness status"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEALTH_CHECK_RESPONSE_FIELD_NUMBER: builtins.int
    @property
    def health_check_response(self) -> common.healthcheck.v1beta.healthcheck_pb2.HealthCheckResponse:
        """HealthCheckResponse message"""
    def __init__(
        self,
        *,
        health_check_response: common.healthcheck.v1beta.healthcheck_pb2.HealthCheckResponse | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["health_check_response", b"health_check_response"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["health_check_response", b"health_check_response"]) -> None: ...

global___LivenessResponse = LivenessResponse

@typing_extensions.final
class ReadinessRequest(google.protobuf.message.Message):
    """ReadinessRequest represents a request to check a service readiness status"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEALTH_CHECK_REQUEST_FIELD_NUMBER: builtins.int
    @property
    def health_check_request(self) -> common.healthcheck.v1beta.healthcheck_pb2.HealthCheckRequest:
        """HealthCheckRequest message"""
    def __init__(
        self,
        *,
        health_check_request: common.healthcheck.v1beta.healthcheck_pb2.HealthCheckRequest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_health_check_request", b"_health_check_request", "health_check_request", b"health_check_request"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_health_check_request", b"_health_check_request", "health_check_request", b"health_check_request"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_health_check_request", b"_health_check_request"]) -> typing_extensions.Literal["health_check_request"] | None: ...

global___ReadinessRequest = ReadinessRequest

@typing_extensions.final
class ReadinessResponse(google.protobuf.message.Message):
    """ReadinessResponse represents a response for a service readiness status"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEALTH_CHECK_RESPONSE_FIELD_NUMBER: builtins.int
    @property
    def health_check_response(self) -> common.healthcheck.v1beta.healthcheck_pb2.HealthCheckResponse:
        """HealthCheckResponse message"""
    def __init__(
        self,
        *,
        health_check_response: common.healthcheck.v1beta.healthcheck_pb2.HealthCheckResponse | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["health_check_response", b"health_check_response"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["health_check_response", b"health_check_response"]) -> None: ...

global___ReadinessResponse = ReadinessResponse

@typing_extensions.final
class App(google.protobuf.message.Message):
    """
    This API is under development and, therefore, some of its entities and
    endpoints are not implemented yet. This section aims to give context about
    the current interface and how it fits in the App vision.

    # App

    The App domain is responsible of ready-to-use AI applications.

    App represents a app.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APP_ID_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    CREATE_TIME_FIELD_NUMBER: builtins.int
    UPDATE_TIME_FIELD_NUMBER: builtins.int
    OWNER_UID_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    AI_ASSISTANT_APP_FIELD_NUMBER: builtins.int
    APP_TYPE_FIELD_NUMBER: builtins.int
    APP_UID_FIELD_NUMBER: builtins.int
    CREATOR_UID_FIELD_NUMBER: builtins.int
    app_id: builtins.str
    """The app id."""
    description: builtins.str
    """The app description."""
    @property
    def create_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The creation time of the app."""
    @property
    def update_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The last update time of the app."""
    owner_uid: builtins.str
    """The owner/namespace of the app."""
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """The app tags."""
    @property
    def ai_assistant_app(self) -> global___AIAssistantAppMetadata:
        """The AI assistant app metadata."""
    app_type: global___AppType.ValueType
    """The app type."""
    app_uid: builtins.str
    """app uid"""
    creator_uid: builtins.str
    """creator uid"""
    def __init__(
        self,
        *,
        app_id: builtins.str = ...,
        description: builtins.str = ...,
        create_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        update_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        owner_uid: builtins.str = ...,
        tags: collections.abc.Iterable[builtins.str] | None = ...,
        ai_assistant_app: global___AIAssistantAppMetadata | None = ...,
        app_type: global___AppType.ValueType = ...,
        app_uid: builtins.str = ...,
        creator_uid: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["ai_assistant_app", b"ai_assistant_app", "create_time", b"create_time", "metadata", b"metadata", "update_time", b"update_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ai_assistant_app", b"ai_assistant_app", "app_id", b"app_id", "app_type", b"app_type", "app_uid", b"app_uid", "create_time", b"create_time", "creator_uid", b"creator_uid", "description", b"description", "metadata", b"metadata", "owner_uid", b"owner_uid", "tags", b"tags", "update_time", b"update_time"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["metadata", b"metadata"]) -> typing_extensions.Literal["ai_assistant_app"] | None: ...

global___App = App

@typing_extensions.final
class AIAssistantAppMetadata(google.protobuf.message.Message):
    """AIAssistantAppMetadata represents the metadata for the AI assistant app."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CATALOG_UID_FIELD_NUMBER: builtins.int
    TOP_K_FIELD_NUMBER: builtins.int
    catalog_uid: builtins.str
    """The AI assistant app catalog uid."""
    top_k: builtins.int
    """The AI assistant app top k."""
    def __init__(
        self,
        *,
        catalog_uid: builtins.str = ...,
        top_k: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["catalog_uid", b"catalog_uid", "top_k", b"top_k"]) -> None: ...

global___AIAssistantAppMetadata = AIAssistantAppMetadata

@typing_extensions.final
class CreateAppRequest(google.protobuf.message.Message):
    """CreateAppRequest represents a request to create a app."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """The app's owner(namespaces)."""
    id: builtins.str
    """The app id.
    the app id should be lowercase without any space or special character besides the hyphen,
    it can not start with number or hyphen, and should be less than 32 characters.
    """
    description: builtins.str
    """The app description."""
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """The app tags."""
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        id: builtins.str = ...,
        description: builtins.str = ...,
        tags: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "id", b"id", "namespace_id", b"namespace_id", "tags", b"tags"]) -> None: ...

global___CreateAppRequest = CreateAppRequest

@typing_extensions.final
class CreateAppResponse(google.protobuf.message.Message):
    """CreateAppResponse represents a response for creating a app."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APP_FIELD_NUMBER: builtins.int
    @property
    def app(self) -> global___App:
        """The created app."""
    def __init__(
        self,
        *,
        app: global___App | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["app", b"app"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["app", b"app"]) -> None: ...

global___CreateAppResponse = CreateAppResponse

@typing_extensions.final
class ListAppsRequest(google.protobuf.message.Message):
    """Request message for ListApps"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """User ID for which to list the apps"""
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["namespace_id", b"namespace_id"]) -> None: ...

global___ListAppsRequest = ListAppsRequest

@typing_extensions.final
class ListAppsResponse(google.protobuf.message.Message):
    """GetAppsResponse represents a response for getting all apps from users."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPS_FIELD_NUMBER: builtins.int
    @property
    def apps(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___App]:
        """The apps container."""
    def __init__(
        self,
        *,
        apps: collections.abc.Iterable[global___App] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["apps", b"apps"]) -> None: ...

global___ListAppsResponse = ListAppsResponse

@typing_extensions.final
class UpdateAppRequest(google.protobuf.message.Message):
    """UpdateAppRequest represents a request to update a app."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    APP_ID_FIELD_NUMBER: builtins.int
    NEW_APP_ID_FIELD_NUMBER: builtins.int
    NEW_DESCRIPTION_FIELD_NUMBER: builtins.int
    NEW_TAGS_FIELD_NUMBER: builtins.int
    LAST_AI_ASSISTANT_APP_CATALOG_UID_FIELD_NUMBER: builtins.int
    LAST_AI_ASSISTANT_APP_TOP_K_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """Namespace id."""
    app_id: builtins.str
    """App id."""
    new_app_id: builtins.str
    """The app id needs to follow the kebab case format.
    if the new app id is not provided, the app id will not be updated.
    """
    new_description: builtins.str
    """The app description.
    If the new description is empty, the description will be set to empty.
    """
    @property
    def new_tags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """The app tags.
        If the new tags is empty, the tags will be set to empty.
        """
    last_ai_assistant_app_catalog_uid: builtins.str
    """last AI assistant app catalog uid
    If the last AI assistant app catalog uid is empty, the last AI assistant app catalog uid will be set to empty.
    """
    last_ai_assistant_app_top_k: builtins.int
    """last AI assistant app top k
    If the last AI assistant app top k is empty, the last AI assistant app top k will be set to empty.
    """
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        app_id: builtins.str = ...,
        new_app_id: builtins.str = ...,
        new_description: builtins.str = ...,
        new_tags: collections.abc.Iterable[builtins.str] | None = ...,
        last_ai_assistant_app_catalog_uid: builtins.str = ...,
        last_ai_assistant_app_top_k: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_id", b"app_id", "last_ai_assistant_app_catalog_uid", b"last_ai_assistant_app_catalog_uid", "last_ai_assistant_app_top_k", b"last_ai_assistant_app_top_k", "namespace_id", b"namespace_id", "new_app_id", b"new_app_id", "new_description", b"new_description", "new_tags", b"new_tags"]) -> None: ...

global___UpdateAppRequest = UpdateAppRequest

@typing_extensions.final
class UpdateAppResponse(google.protobuf.message.Message):
    """UpdateAppResponse represents a response for updating a app."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APP_FIELD_NUMBER: builtins.int
    @property
    def app(self) -> global___App:
        """The updated app."""
    def __init__(
        self,
        *,
        app: global___App | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["app", b"app"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["app", b"app"]) -> None: ...

global___UpdateAppResponse = UpdateAppResponse

@typing_extensions.final
class DeleteAppRequest(google.protobuf.message.Message):
    """DeleteAppRequest represents a request to delete a app."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    APP_ID_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """The owner's id. i.e. namespace."""
    app_id: builtins.str
    """The app id."""
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        app_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_id", b"app_id", "namespace_id", b"namespace_id"]) -> None: ...

global___DeleteAppRequest = DeleteAppRequest

@typing_extensions.final
class DeleteAppResponse(google.protobuf.message.Message):
    """DeleteAppResponse represents a response for deleting a app."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteAppResponse = DeleteAppResponse

@typing_extensions.final
class RestartPlaygroundConversationRequest(google.protobuf.message.Message):
    """RestartPlaygroundConversationRequest represents a request to restart a playground conversation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    APP_ID_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """The namespace id."""
    app_id: builtins.str
    """The app id."""
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        app_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_id", b"app_id", "namespace_id", b"namespace_id"]) -> None: ...

global___RestartPlaygroundConversationRequest = RestartPlaygroundConversationRequest

@typing_extensions.final
class RestartPlaygroundConversationResponse(google.protobuf.message.Message):
    """RestartPlaygroundConversationResponse represents a response for restarting a playground conversation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONVERSATION_FIELD_NUMBER: builtins.int
    @property
    def conversation(self) -> app.app.v1alpha.conversation_pb2.Conversation:
        """conversation"""
    def __init__(
        self,
        *,
        conversation: app.app.v1alpha.conversation_pb2.Conversation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["conversation", b"conversation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["conversation", b"conversation"]) -> None: ...

global___RestartPlaygroundConversationResponse = RestartPlaygroundConversationResponse

@typing_extensions.final
class GetPlaygroundConversationRequest(google.protobuf.message.Message):
    """GetPlaygroundConversationRequest represents a request to get a playground conversation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    APP_ID_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """The namespace id."""
    app_id: builtins.str
    """The app id."""
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        app_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_id", b"app_id", "namespace_id", b"namespace_id"]) -> None: ...

global___GetPlaygroundConversationRequest = GetPlaygroundConversationRequest

@typing_extensions.final
class GetPlaygroundConversationResponse(google.protobuf.message.Message):
    """GetPlaygroundConversationResponse represents a response for getting a playground conversation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONVERSATION_FIELD_NUMBER: builtins.int
    @property
    def conversation(self) -> app.app.v1alpha.conversation_pb2.Conversation:
        """conversation"""
    def __init__(
        self,
        *,
        conversation: app.app.v1alpha.conversation_pb2.Conversation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["conversation", b"conversation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["conversation", b"conversation"]) -> None: ...

global___GetPlaygroundConversationResponse = GetPlaygroundConversationResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: artifact/artifact/v1alpha/artifact_public_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from artifact.artifact.v1alpha import artifact_pb2 as artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2
from artifact.artifact.v1alpha import chunk_pb2 as artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2
from artifact.artifact.v1alpha import file_catalog_pb2 as artifact_dot_artifact_dot_v1alpha_dot_file__catalog__pb2
from artifact.artifact.v1alpha import object_pb2 as artifact_dot_artifact_dot_v1alpha_dot_object__pb2
from artifact.artifact.v1alpha import qa_pb2 as artifact_dot_artifact_dot_v1alpha_dot_qa__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7artifact/artifact/v1alpha/artifact_public_service.proto\x12\x19\x61rtifact.artifact.v1alpha\x1a(artifact/artifact/v1alpha/artifact.proto\x1a%artifact/artifact/v1alpha/chunk.proto\x1a,artifact/artifact/v1alpha/file_catalog.proto\x1a&artifact/artifact/v1alpha/object.proto\x1a\"artifact/artifact/v1alpha/qa.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/api/visibility.proto\x1a.protoc-gen-openapiv2/options/annotations.proto2\xd6!\n\x15\x41rtifactPublicService\x12\xac\x01\n\x08Liveness\x12*.artifact.artifact.v1alpha.LivenessRequest\x1a+.artifact.artifact.v1alpha.LivenessResponse\"G\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x31\x12\x13/v1alpha/__livenessZ\x1a\x12\x18/v1alpha/health/artifact\x12\xaf\x01\n\tReadiness\x12+.artifact.artifact.v1alpha.ReadinessRequest\x1a,.artifact.artifact.v1alpha.ReadinessResponse\"G\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x31\x12\x14/v1alpha/__readinessZ\x19\x12\x17/v1alpha/ready/artifact\x12\xb6\x01\n\rCreateCatalog\x12/.artifact.artifact.v1alpha.CreateCatalogRequest\x1a\x30.artifact.artifact.v1alpha.CreateCatalogResponse\"B\x92\x41\t\n\x07\x43\x61talog\x82\xd3\xe4\x93\x02\x30\"+/v1alpha/namespaces/{namespace_id}/catalogs:\x01*\x12\xb0\x01\n\x0cListCatalogs\x12..artifact.artifact.v1alpha.ListCatalogsRequest\x1a/.artifact.artifact.v1alpha.ListCatalogsResponse\"?\x92\x41\t\n\x07\x43\x61talog\x82\xd3\xe4\x93\x02-\x12+/v1alpha/namespaces/{namespace_id}/catalogs\x12\xc3\x01\n\rUpdateCatalog\x12/.artifact.artifact.v1alpha.UpdateCatalogRequest\x1a\x30.artifact.artifact.v1alpha.UpdateCatalogResponse\"O\x92\x41\t\n\x07\x43\x61talog\x82\xd3\xe4\x93\x02=\x1a\x38/v1alpha/namespaces/{namespace_id}/catalogs/{catalog_id}:\x01*\x12\xc0\x01\n\rDeleteCatalog\x12/.artifact.artifact.v1alpha.DeleteCatalogRequest\x1a\x30.artifact.artifact.v1alpha.DeleteCatalogResponse\"L\x92\x41\t\n\x07\x43\x61talog\x82\xd3\xe4\x93\x02:*8/v1alpha/namespaces/{namespace_id}/catalogs/{catalog_id}\x12\xd8\x01\n\x11UploadCatalogFile\x12\x33.artifact.artifact.v1alpha.UploadCatalogFileRequest\x1a\x34.artifact.artifact.v1alpha.UploadCatalogFileResponse\"X\x92\x41\t\n\x07\x43\x61talog\x82\xd3\xe4\x93\x02\x46\">/v1alpha/namespaces/{namespace_id}/catalogs/{catalog_id}/files:\x04\x66ile\x12\xab\x01\n\x11\x44\x65leteCatalogFile\x12\x33.artifact.artifact.v1alpha.DeleteCatalogFileRequest\x1a\x34.artifact.artifact.v1alpha.DeleteCatalogFileResponse\"+\x92\x41\t\n\x07\x43\x61talog\x82\xd3\xe4\x93\x02\x19*\x17/v1alpha/catalogs/files\x12\xe6\x02\n\x13ProcessCatalogFiles\x12\x35.artifact.artifact.v1alpha.ProcessCatalogFilesRequest\x1a\x36.artifact.artifact.v1alpha.ProcessCatalogFilesResponse\"\xdf\x01\x92\x41\xac\x01\n\x07\x43\x61talogr\xa0\x01\n\x9d\x01\n\x15Instill-Requester-Uid\x12\x81\x01Indicates the authenticated namespace is making the request on behalf of another entity, typically an organization they belong to\x18\x01\x82\xd3\xe4\x93\x02)\"$/v1alpha/catalogs/files/processAsync:\x01*\x12\xcf\x01\n\x10ListCatalogFiles\x12\x32.artifact.artifact.v1alpha.ListCatalogFilesRequest\x1a\x33.artifact.artifact.v1alpha.ListCatalogFilesResponse\"R\x92\x41\t\n\x07\x43\x61talog\x82\xd3\xe4\x93\x02@\x12>/v1alpha/namespaces/{namespace_id}/catalogs/{catalog_id}/files\x12\xbe\x01\n\nListChunks\x12,.artifact.artifact.v1alpha.ListChunksRequest\x1a-.artifact.artifact.v1alpha.ListChunksResponse\"S\x92\x41\t\n\x07\x43\x61talog\x82\xd3\xe4\x93\x02\x41\x12?/v1alpha/namespaces/{namespace_id}/catalogs/{catalog_id}/chunks\x12\xd8\x01\n\rGetSourceFile\x12/.artifact.artifact.v1alpha.GetSourceFileRequest\x1a\x30.artifact.artifact.v1alpha.GetSourceFileResponse\"d\x92\x41\t\n\x07\x43\x61talog\x82\xd3\xe4\x93\x02R\x12P/v1alpha/namespaces/{namespace_id}/catalogs/{catalog_id}/files/{file_uid}/source\x12\xa0\x01\n\x0bUpdateChunk\x12-.artifact.artifact.v1alpha.UpdateChunkRequest\x1a..artifact.artifact.v1alpha.UpdateChunkResponse\"2\x92\x41\t\n\x07\x43\x61talog\x82\xd3\xe4\x93\x02 \"\x1b/v1alpha/chunks/{chunk_uid}:\x01*\x12\x93\x03\n\x16SimilarityChunksSearch\x12\x38.artifact.artifact.v1alpha.SimilarityChunksSearchRequest\x1a\x39.artifact.artifact.v1alpha.SimilarityChunksSearchResponse\"\x83\x02\x92\x41\xac\x01\n\x07\x43\x61talogr\xa0\x01\n\x9d\x01\n\x15Instill-Requester-Uid\x12\x81\x01Indicates the authenticated namespace is making the request on behalf of another entity, typically an organization they belong to\x18\x01\x82\xd3\xe4\x93\x02M\"H/v1alpha/namespaces/{namespace_id}/catalogs/{catalog_id}/chunks/retrieve:\x01*\x12\xf8\x02\n\x11QuestionAnswering\x12\x33.artifact.artifact.v1alpha.QuestionAnsweringRequest\x1a\x34.artifact.artifact.v1alpha.QuestionAnsweringResponse\"\xf7\x01\x92\x41\xac\x01\n\x07\x43\x61talogr\xa0\x01\n\x9d\x01\n\x15Instill-Requester-Uid\x12\x81\x01Indicates the authenticated namespace is making the request on behalf of another entity, typically an organization they belong to\x18\x01\x82\xd3\xe4\x93\x02\x41\"</v1alpha/namespaces/{namespace_id}/catalogs/{catalog_id}/ask:\x01*\x12\xc3\x01\n\x0eGetFileCatalog\x12\x30.artifact.artifact.v1alpha.GetFileCatalogRequest\x1a\x31.artifact.artifact.v1alpha.GetFileCatalogResponse\"L\x92\x41\t\n\x07\x43\x61talog\x82\xd3\xe4\x93\x02:\x12\x38/v1alpha/namespaces/{namespace_id}/catalogs/{catalog_id}\x12\xca\x01\n\x0fListCatalogRuns\x12\x31.artifact.artifact.v1alpha.ListCatalogRunsRequest\x1a\x32.artifact.artifact.v1alpha.ListCatalogRunsResponse\"P\x92\x41\t\n\x07\x43\x61talog\x82\xd3\xe4\x93\x02>\x12</v1beta/namespaces/{namespace_id}/catalogs/{catalog_id}/runs\x12\xca\x01\n\x12GetObjectUploadURL\x12\x34.artifact.artifact.v1alpha.GetObjectUploadURLRequest\x1a\x35.artifact.artifact.v1alpha.GetObjectUploadURLResponse\"G\x92\x41\x08\n\x06Object\x82\xd3\xe4\x93\x02\x36\x12\x34/v1alpha/namespaces/{namespace_id}/object-upload-url\x12\xd2\x01\n\x14GetObjectDownloadURL\x12\x36.artifact.artifact.v1alpha.GetObjectDownloadURLRequest\x1a\x37.artifact.artifact.v1alpha.GetObjectDownloadURLResponse\"I\x92\x41\x08\n\x06Object\x82\xd3\xe4\x93\x02\x38\x12\x36/v1alpha/namespaces/{namespace_id}/object-download-url\x1a\x1e\x92\x41\x1b\x12\x19Public Artifact endpointsB\x8e\x02\n\x1d\x63om.artifact.artifact.v1alphaB\x1a\x41rtifactPublicServiceProtoP\x01ZKgithub.com/instill-ai/protogen-go/artifact/artifact/v1alpha;artifactv1alpha\xa2\x02\x03\x41\x41X\xaa\x02\x19\x41rtifact.Artifact.V1alpha\xca\x02\x19\x41rtifact\\Artifact\\V1alpha\xe2\x02%Artifact\\Artifact\\V1alpha\\GPBMetadata\xea\x02\x1b\x41rtifact::Artifact::V1alphab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'artifact.artifact.v1alpha.artifact_public_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035com.artifact.artifact.v1alphaB\032ArtifactPublicServiceProtoP\001ZKgithub.com/instill-ai/protogen-go/artifact/artifact/v1alpha;artifactv1alpha\242\002\003AAX\252\002\031Artifact.Artifact.V1alpha\312\002\031Artifact\\Artifact\\V1alpha\342\002%Artifact\\Artifact\\V1alpha\\GPBMetadata\352\002\033Artifact::Artifact::V1alpha'
  _ARTIFACTPUBLICSERVICE._options = None
  _ARTIFACTPUBLICSERVICE._serialized_options = b'\222A\033\022\031Public Artifact endpoints'
  _ARTIFACTPUBLICSERVICE.methods_by_name['Liveness']._options = None
  _ARTIFACTPUBLICSERVICE.methods_by_name['Liveness']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\0021\022\023/v1alpha/__livenessZ\032\022\030/v1alpha/health/artifact'
  _ARTIFACTPUBLICSERVICE.methods_by_name['Readiness']._options = None
  _ARTIFACTPUBLICSERVICE.methods_by_name['Readiness']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\0021\022\024/v1alpha/__readinessZ\031\022\027/v1alpha/ready/artifact'
  _ARTIFACTPUBLICSERVICE.methods_by_name['CreateCatalog']._options = None
  _ARTIFACTPUBLICSERVICE.methods_by_name['CreateCatalog']._serialized_options = b'\222A\t\n\007Catalog\202\323\344\223\0020\"+/v1alpha/namespaces/{namespace_id}/catalogs:\001*'
  _ARTIFACTPUBLICSERVICE.methods_by_name['ListCatalogs']._options = None
  _ARTIFACTPUBLICSERVICE.methods_by_name['ListCatalogs']._serialized_options = b'\222A\t\n\007Catalog\202\323\344\223\002-\022+/v1alpha/namespaces/{namespace_id}/catalogs'
  _ARTIFACTPUBLICSERVICE.methods_by_name['UpdateCatalog']._options = None
  _ARTIFACTPUBLICSERVICE.methods_by_name['UpdateCatalog']._serialized_options = b'\222A\t\n\007Catalog\202\323\344\223\002=\0328/v1alpha/namespaces/{namespace_id}/catalogs/{catalog_id}:\001*'
  _ARTIFACTPUBLICSERVICE.methods_by_name['DeleteCatalog']._options = None
  _ARTIFACTPUBLICSERVICE.methods_by_name['DeleteCatalog']._serialized_options = b'\222A\t\n\007Catalog\202\323\344\223\002:*8/v1alpha/namespaces/{namespace_id}/catalogs/{catalog_id}'
  _ARTIFACTPUBLICSERVICE.methods_by_name['UploadCatalogFile']._options = None
  _ARTIFACTPUBLICSERVICE.methods_by_name['UploadCatalogFile']._serialized_options = b'\222A\t\n\007Catalog\202\323\344\223\002F\">/v1alpha/namespaces/{namespace_id}/catalogs/{catalog_id}/files:\004file'
  _ARTIFACTPUBLICSERVICE.methods_by_name['DeleteCatalogFile']._options = None
  _ARTIFACTPUBLICSERVICE.methods_by_name['DeleteCatalogFile']._serialized_options = b'\222A\t\n\007Catalog\202\323\344\223\002\031*\027/v1alpha/catalogs/files'
  _ARTIFACTPUBLICSERVICE.methods_by_name['ProcessCatalogFiles']._options = None
  _ARTIFACTPUBLICSERVICE.methods_by_name['ProcessCatalogFiles']._serialized_options = b'\222A\254\001\n\007Catalogr\240\001\n\235\001\n\025Instill-Requester-Uid\022\201\001Indicates the authenticated namespace is making the request on behalf of another entity, typically an organization they belong to\030\001\202\323\344\223\002)\"$/v1alpha/catalogs/files/processAsync:\001*'
  _ARTIFACTPUBLICSERVICE.methods_by_name['ListCatalogFiles']._options = None
  _ARTIFACTPUBLICSERVICE.methods_by_name['ListCatalogFiles']._serialized_options = b'\222A\t\n\007Catalog\202\323\344\223\002@\022>/v1alpha/namespaces/{namespace_id}/catalogs/{catalog_id}/files'
  _ARTIFACTPUBLICSERVICE.methods_by_name['ListChunks']._options = None
  _ARTIFACTPUBLICSERVICE.methods_by_name['ListChunks']._serialized_options = b'\222A\t\n\007Catalog\202\323\344\223\002A\022?/v1alpha/namespaces/{namespace_id}/catalogs/{catalog_id}/chunks'
  _ARTIFACTPUBLICSERVICE.methods_by_name['GetSourceFile']._options = None
  _ARTIFACTPUBLICSERVICE.methods_by_name['GetSourceFile']._serialized_options = b'\222A\t\n\007Catalog\202\323\344\223\002R\022P/v1alpha/namespaces/{namespace_id}/catalogs/{catalog_id}/files/{file_uid}/source'
  _ARTIFACTPUBLICSERVICE.methods_by_name['UpdateChunk']._options = None
  _ARTIFACTPUBLICSERVICE.methods_by_name['UpdateChunk']._serialized_options = b'\222A\t\n\007Catalog\202\323\344\223\002 \"\033/v1alpha/chunks/{chunk_uid}:\001*'
  _ARTIFACTPUBLICSERVICE.methods_by_name['SimilarityChunksSearch']._options = None
  _ARTIFACTPUBLICSERVICE.methods_by_name['SimilarityChunksSearch']._serialized_options = b'\222A\254\001\n\007Catalogr\240\001\n\235\001\n\025Instill-Requester-Uid\022\201\001Indicates the authenticated namespace is making the request on behalf of another entity, typically an organization they belong to\030\001\202\323\344\223\002M\"H/v1alpha/namespaces/{namespace_id}/catalogs/{catalog_id}/chunks/retrieve:\001*'
  _ARTIFACTPUBLICSERVICE.methods_by_name['QuestionAnswering']._options = None
  _ARTIFACTPUBLICSERVICE.methods_by_name['QuestionAnswering']._serialized_options = b'\222A\254\001\n\007Catalogr\240\001\n\235\001\n\025Instill-Requester-Uid\022\201\001Indicates the authenticated namespace is making the request on behalf of another entity, typically an organization they belong to\030\001\202\323\344\223\002A\"</v1alpha/namespaces/{namespace_id}/catalogs/{catalog_id}/ask:\001*'
  _ARTIFACTPUBLICSERVICE.methods_by_name['GetFileCatalog']._options = None
  _ARTIFACTPUBLICSERVICE.methods_by_name['GetFileCatalog']._serialized_options = b'\222A\t\n\007Catalog\202\323\344\223\002:\0228/v1alpha/namespaces/{namespace_id}/catalogs/{catalog_id}'
  _ARTIFACTPUBLICSERVICE.methods_by_name['ListCatalogRuns']._options = None
  _ARTIFACTPUBLICSERVICE.methods_by_name['ListCatalogRuns']._serialized_options = b'\222A\t\n\007Catalog\202\323\344\223\002>\022</v1beta/namespaces/{namespace_id}/catalogs/{catalog_id}/runs'
  _ARTIFACTPUBLICSERVICE.methods_by_name['GetObjectUploadURL']._options = None
  _ARTIFACTPUBLICSERVICE.methods_by_name['GetObjectUploadURL']._serialized_options = b'\222A\010\n\006Object\202\323\344\223\0026\0224/v1alpha/namespaces/{namespace_id}/object-upload-url'
  _ARTIFACTPUBLICSERVICE.methods_by_name['GetObjectDownloadURL']._options = None
  _ARTIFACTPUBLICSERVICE.methods_by_name['GetObjectDownloadURL']._serialized_options = b'\222A\010\n\006Object\202\323\344\223\0028\0226/v1alpha/namespaces/{namespace_id}/object-download-url'
  _globals['_ARTIFACTPUBLICSERVICE']._serialized_start=397
  _globals['_ARTIFACTPUBLICSERVICE']._serialized_end=4707
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import artifact.artifact.v1alpha.chunk_pb2
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.struct_pb2
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Conversation(google.protobuf.message.Message):
    """Conversation represents a chat conversation"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UID_FIELD_NUMBER: builtins.int
    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    APP_ID_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LAST_USED_CATALOG_UID_FIELD_NUMBER: builtins.int
    LAST_USED_TOP_K_FIELD_NUMBER: builtins.int
    CREATE_TIME_FIELD_NUMBER: builtins.int
    UPDATE_TIME_FIELD_NUMBER: builtins.int
    uid: builtins.str
    """unique identifier of the conversation created by the system"""
    namespace_id: builtins.str
    """namespace id"""
    app_id: builtins.str
    """app id"""
    id: builtins.str
    """conversation id/name"""
    last_used_catalog_uid: builtins.str
    """last used catalog uid"""
    last_used_top_k: builtins.int
    """last used top k"""
    @property
    def create_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """creation time of the conversation"""
    @property
    def update_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """update time of the conversation"""
    def __init__(
        self,
        *,
        uid: builtins.str = ...,
        namespace_id: builtins.str = ...,
        app_id: builtins.str = ...,
        id: builtins.str = ...,
        last_used_catalog_uid: builtins.str | None = ...,
        last_used_top_k: builtins.int | None = ...,
        create_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        update_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_last_used_catalog_uid", b"_last_used_catalog_uid", "_last_used_top_k", b"_last_used_top_k", "create_time", b"create_time", "last_used_catalog_uid", b"last_used_catalog_uid", "last_used_top_k", b"last_used_top_k", "update_time", b"update_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_last_used_catalog_uid", b"_last_used_catalog_uid", "_last_used_top_k", b"_last_used_top_k", "app_id", b"app_id", "create_time", b"create_time", "id", b"id", "last_used_catalog_uid", b"last_used_catalog_uid", "last_used_top_k", b"last_used_top_k", "namespace_id", b"namespace_id", "uid", b"uid", "update_time", b"update_time"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_last_used_catalog_uid", b"_last_used_catalog_uid"]) -> typing_extensions.Literal["last_used_catalog_uid"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_last_used_top_k", b"_last_used_top_k"]) -> typing_extensions.Literal["last_used_top_k"] | None: ...

global___Conversation = Conversation

@typing_extensions.final
class Message(google.protobuf.message.Message):
    """Message represents a single message in a conversation"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _MessageType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _MessageTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Message._MessageType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        MESSAGE_TYPE_UNSPECIFIED: Message._MessageType.ValueType  # 0
        """unspecified"""
        MESSAGE_TYPE_TEXT: Message._MessageType.ValueType  # 1
        """text"""

    class MessageType(_MessageType, metaclass=_MessageTypeEnumTypeWrapper):
        """message type"""

    MESSAGE_TYPE_UNSPECIFIED: Message.MessageType.ValueType  # 0
    """unspecified"""
    MESSAGE_TYPE_TEXT: Message.MessageType.ValueType  # 1
    """text"""

    UID_FIELD_NUMBER: builtins.int
    APP_UID_FIELD_NUMBER: builtins.int
    CONVERSATION_UID_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    CREATE_TIME_FIELD_NUMBER: builtins.int
    UPDATE_TIME_FIELD_NUMBER: builtins.int
    MSG_SENDER_UID_FIELD_NUMBER: builtins.int
    uid: builtins.str
    """message uid"""
    app_uid: builtins.str
    """app uid"""
    conversation_uid: builtins.str
    """conversation uid"""
    content: builtins.str
    """message content"""
    role: builtins.str
    """message role e.g., "user" or "assistant" """
    type: global___Message.MessageType.ValueType
    """message type"""
    @property
    def create_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """creation time of the message"""
    @property
    def update_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """update time of the message"""
    msg_sender_uid: builtins.str
    """message sender uid"""
    def __init__(
        self,
        *,
        uid: builtins.str = ...,
        app_uid: builtins.str = ...,
        conversation_uid: builtins.str = ...,
        content: builtins.str = ...,
        role: builtins.str = ...,
        type: global___Message.MessageType.ValueType = ...,
        create_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        update_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        msg_sender_uid: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["create_time", b"create_time", "update_time", b"update_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_uid", b"app_uid", "content", b"content", "conversation_uid", b"conversation_uid", "create_time", b"create_time", "msg_sender_uid", b"msg_sender_uid", "role", b"role", "type", b"type", "uid", b"uid", "update_time", b"update_time"]) -> None: ...

global___Message = Message

@typing_extensions.final
class CreateConversationRequest(google.protobuf.message.Message):
    """CreateConversationRequest is used to create a new conversation"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    APP_ID_FIELD_NUMBER: builtins.int
    CONVERSATION_ID_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """namespace id"""
    app_id: builtins.str
    """app id"""
    conversation_id: builtins.str
    """conversation id. only allow kebab case"""
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        app_id: builtins.str = ...,
        conversation_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_id", b"app_id", "conversation_id", b"conversation_id", "namespace_id", b"namespace_id"]) -> None: ...

global___CreateConversationRequest = CreateConversationRequest

@typing_extensions.final
class CreateConversationResponse(google.protobuf.message.Message):
    """CreateConversationResponse returns the created conversation"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONVERSATION_FIELD_NUMBER: builtins.int
    @property
    def conversation(self) -> global___Conversation:
        """conversation"""
    def __init__(
        self,
        *,
        conversation: global___Conversation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["conversation", b"conversation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["conversation", b"conversation"]) -> None: ...

global___CreateConversationResponse = CreateConversationResponse

@typing_extensions.final
class ListConversationsRequest(google.protobuf.message.Message):
    """ListConversationsRequest is used to list conversations"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    APP_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    CONVERSATION_UID_FIELD_NUMBER: builtins.int
    CONVERSATION_ID_FIELD_NUMBER: builtins.int
    IF_ALL_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """namespace id"""
    app_id: builtins.str
    """app id"""
    page_size: builtins.int
    """page size"""
    page_token: builtins.str
    """page token"""
    conversation_uid: builtins.str
    """conversation_uid this is optional, if provided, only the conversation with the given conversation_uid will be returned
    first check conversation_uid, then check conversation_id, then check if_all
    """
    conversation_id: builtins.str
    """conversation_id this is optional, if provided, only the conversation with the given conversation_id will be returned"""
    if_all: builtins.bool
    """If true, all conversations will be returned. This has higher priority over conversation_id, page_size, and page_token."""
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        app_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        conversation_uid: builtins.str = ...,
        conversation_id: builtins.str = ...,
        if_all: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_id", b"app_id", "conversation_id", b"conversation_id", "conversation_uid", b"conversation_uid", "if_all", b"if_all", "namespace_id", b"namespace_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListConversationsRequest = ListConversationsRequest

@typing_extensions.final
class ListConversationsResponse(google.protobuf.message.Message):
    """ListConversationsResponse returns a list of conversations"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONVERSATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    TOTAL_SIZE_FIELD_NUMBER: builtins.int
    @property
    def conversations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Conversation]:
        """conversations"""
    next_page_token: builtins.str
    """next page token"""
    total_size: builtins.int
    """total size"""
    def __init__(
        self,
        *,
        conversations: collections.abc.Iterable[global___Conversation] | None = ...,
        next_page_token: builtins.str = ...,
        total_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["conversations", b"conversations", "next_page_token", b"next_page_token", "total_size", b"total_size"]) -> None: ...

global___ListConversationsResponse = ListConversationsResponse

@typing_extensions.final
class UpdateConversationRequest(google.protobuf.message.Message):
    """UpdateConversationRequest is used to update a conversation"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    APP_ID_FIELD_NUMBER: builtins.int
    CONVERSATION_ID_FIELD_NUMBER: builtins.int
    NEW_CONVERSATION_ID_FIELD_NUMBER: builtins.int
    LAST_USED_CATALOG_UID_FIELD_NUMBER: builtins.int
    LAST_USED_TOP_K_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """namespace id"""
    app_id: builtins.str
    """app id"""
    conversation_id: builtins.str
    """conversation id"""
    new_conversation_id: builtins.str
    """new conversation id"""
    last_used_catalog_uid: builtins.str
    """last used catalog uid"""
    last_used_top_k: builtins.int
    """last used top k"""
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        app_id: builtins.str = ...,
        conversation_id: builtins.str = ...,
        new_conversation_id: builtins.str | None = ...,
        last_used_catalog_uid: builtins.str | None = ...,
        last_used_top_k: builtins.int | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_last_used_catalog_uid", b"_last_used_catalog_uid", "_last_used_top_k", b"_last_used_top_k", "_new_conversation_id", b"_new_conversation_id", "last_used_catalog_uid", b"last_used_catalog_uid", "last_used_top_k", b"last_used_top_k", "new_conversation_id", b"new_conversation_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_last_used_catalog_uid", b"_last_used_catalog_uid", "_last_used_top_k", b"_last_used_top_k", "_new_conversation_id", b"_new_conversation_id", "app_id", b"app_id", "conversation_id", b"conversation_id", "last_used_catalog_uid", b"last_used_catalog_uid", "last_used_top_k", b"last_used_top_k", "namespace_id", b"namespace_id", "new_conversation_id", b"new_conversation_id"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_last_used_catalog_uid", b"_last_used_catalog_uid"]) -> typing_extensions.Literal["last_used_catalog_uid"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_last_used_top_k", b"_last_used_top_k"]) -> typing_extensions.Literal["last_used_top_k"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_new_conversation_id", b"_new_conversation_id"]) -> typing_extensions.Literal["new_conversation_id"] | None: ...

global___UpdateConversationRequest = UpdateConversationRequest

@typing_extensions.final
class UpdateConversationResponse(google.protobuf.message.Message):
    """UpdateConversationResponse returns the updated conversation"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONVERSATION_FIELD_NUMBER: builtins.int
    @property
    def conversation(self) -> global___Conversation:
        """conversation"""
    def __init__(
        self,
        *,
        conversation: global___Conversation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["conversation", b"conversation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["conversation", b"conversation"]) -> None: ...

global___UpdateConversationResponse = UpdateConversationResponse

@typing_extensions.final
class DeleteConversationRequest(google.protobuf.message.Message):
    """DeleteConversationRequest is used to delete a conversation"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    APP_ID_FIELD_NUMBER: builtins.int
    CONVERSATION_ID_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """namespace id"""
    app_id: builtins.str
    """app id"""
    conversation_id: builtins.str
    """conversation id"""
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        app_id: builtins.str = ...,
        conversation_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_id", b"app_id", "conversation_id", b"conversation_id", "namespace_id", b"namespace_id"]) -> None: ...

global___DeleteConversationRequest = DeleteConversationRequest

@typing_extensions.final
class DeleteConversationResponse(google.protobuf.message.Message):
    """DeleteConversationResponse is empty as no content needs to be returned"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteConversationResponse = DeleteConversationResponse

@typing_extensions.final
class CreateMessageRequest(google.protobuf.message.Message):
    """CreateMessageRequest is used to create a new message"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    APP_ID_FIELD_NUMBER: builtins.int
    CONVERSATION_ID_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """namespace id"""
    app_id: builtins.str
    """app id"""
    conversation_id: builtins.str
    """conversation id"""
    content: builtins.str
    """message content"""
    role: builtins.str
    """message role"""
    type: global___Message.MessageType.ValueType
    """message type"""
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        app_id: builtins.str = ...,
        conversation_id: builtins.str = ...,
        content: builtins.str = ...,
        role: builtins.str = ...,
        type: global___Message.MessageType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_id", b"app_id", "content", b"content", "conversation_id", b"conversation_id", "namespace_id", b"namespace_id", "role", b"role", "type", b"type"]) -> None: ...

global___CreateMessageRequest = CreateMessageRequest

@typing_extensions.final
class CreateMessageResponse(google.protobuf.message.Message):
    """CreateMessageResponse returns the created message"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MESSAGE_FIELD_NUMBER: builtins.int
    @property
    def message(self) -> global___Message:
        """message"""
    def __init__(
        self,
        *,
        message: global___Message | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["message", b"message"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["message", b"message"]) -> None: ...

global___CreateMessageResponse = CreateMessageResponse

@typing_extensions.final
class MessageSenderProfile(google.protobuf.message.Message):
    """MessageSenderProfile describes the public data of a message sender.
    refer to core.mgmt.v1beta.UserProfile for more details.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MSG_SENDER_UID_FIELD_NUMBER: builtins.int
    MSG_SENDER_ID_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    AVATAR_FIELD_NUMBER: builtins.int
    msg_sender_uid: builtins.str
    """sender uid"""
    msg_sender_id: builtins.str
    """sender id"""
    display_name: builtins.str
    """Display name."""
    avatar: builtins.str
    """Avatar url. this url might be expired or not exist."""
    def __init__(
        self,
        *,
        msg_sender_uid: builtins.str = ...,
        msg_sender_id: builtins.str = ...,
        display_name: builtins.str | None = ...,
        avatar: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_avatar", b"_avatar", "_display_name", b"_display_name", "avatar", b"avatar", "display_name", b"display_name"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_avatar", b"_avatar", "_display_name", b"_display_name", "avatar", b"avatar", "display_name", b"display_name", "msg_sender_id", b"msg_sender_id", "msg_sender_uid", b"msg_sender_uid"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_avatar", b"_avatar"]) -> typing_extensions.Literal["avatar"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_display_name", b"_display_name"]) -> typing_extensions.Literal["display_name"] | None: ...

global___MessageSenderProfile = MessageSenderProfile

@typing_extensions.final
class ListMessagesRequest(google.protobuf.message.Message):
    """ListMessagesRequest is used to list messages in a conversation"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    APP_ID_FIELD_NUMBER: builtins.int
    CONVERSATION_ID_FIELD_NUMBER: builtins.int
    LATEST_K_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    INCLUDE_SYSTEM_MESSAGES_FIELD_NUMBER: builtins.int
    IF_ALL_FIELD_NUMBER: builtins.int
    MESSAGE_UID_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """namespace id"""
    app_id: builtins.str
    """app id"""
    conversation_id: builtins.str
    """conversation id"""
    latest_k: builtins.int
    """latest k messages"""
    page_size: builtins.int
    """page size"""
    page_token: builtins.str
    """page token"""
    include_system_messages: builtins.bool
    """include system messages"""
    if_all: builtins.bool
    """If true, all messages will be returned. This has higher priority over latest_k, page_size, and page_token."""
    message_uid: builtins.str
    """message_uid this is optional, if provided, only the message with the given message_uid will be returned"""
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        app_id: builtins.str = ...,
        conversation_id: builtins.str = ...,
        latest_k: builtins.int = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        include_system_messages: builtins.bool = ...,
        if_all: builtins.bool = ...,
        message_uid: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_id", b"app_id", "conversation_id", b"conversation_id", "if_all", b"if_all", "include_system_messages", b"include_system_messages", "latest_k", b"latest_k", "message_uid", b"message_uid", "namespace_id", b"namespace_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListMessagesRequest = ListMessagesRequest

@typing_extensions.final
class ListMessagesResponse(google.protobuf.message.Message):
    """ListMessagesResponse returns a list of messages"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MESSAGES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    TOTAL_SIZE_FIELD_NUMBER: builtins.int
    SENDER_PROFILES_FIELD_NUMBER: builtins.int
    @property
    def messages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Message]:
        """messages"""
    next_page_token: builtins.str
    """next page token"""
    total_size: builtins.int
    """total size"""
    @property
    def sender_profiles(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MessageSenderProfile]:
        """message sender profiles"""
    def __init__(
        self,
        *,
        messages: collections.abc.Iterable[global___Message] | None = ...,
        next_page_token: builtins.str = ...,
        total_size: builtins.int = ...,
        sender_profiles: collections.abc.Iterable[global___MessageSenderProfile] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["messages", b"messages", "next_page_token", b"next_page_token", "sender_profiles", b"sender_profiles", "total_size", b"total_size"]) -> None: ...

global___ListMessagesResponse = ListMessagesResponse

@typing_extensions.final
class UpdateMessageRequest(google.protobuf.message.Message):
    """UpdateMessageRequest is used to update a message"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    APP_ID_FIELD_NUMBER: builtins.int
    CONVERSATION_ID_FIELD_NUMBER: builtins.int
    MESSAGE_UID_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """namespace id"""
    app_id: builtins.str
    """app id"""
    conversation_id: builtins.str
    """conversation id"""
    message_uid: builtins.str
    """message uid"""
    content: builtins.str
    """new message content"""
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        app_id: builtins.str = ...,
        conversation_id: builtins.str = ...,
        message_uid: builtins.str = ...,
        content: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_id", b"app_id", "content", b"content", "conversation_id", b"conversation_id", "message_uid", b"message_uid", "namespace_id", b"namespace_id"]) -> None: ...

global___UpdateMessageRequest = UpdateMessageRequest

@typing_extensions.final
class UpdateMessageResponse(google.protobuf.message.Message):
    """UpdateMessageResponse returns the updated message"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MESSAGE_FIELD_NUMBER: builtins.int
    @property
    def message(self) -> global___Message:
        """message"""
    def __init__(
        self,
        *,
        message: global___Message | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["message", b"message"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["message", b"message"]) -> None: ...

global___UpdateMessageResponse = UpdateMessageResponse

@typing_extensions.final
class DeleteMessageRequest(google.protobuf.message.Message):
    """DeleteMessageRequest is used to delete a message"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    APP_ID_FIELD_NUMBER: builtins.int
    CONVERSATION_ID_FIELD_NUMBER: builtins.int
    MESSAGE_UID_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """namespace id"""
    app_id: builtins.str
    """app id"""
    conversation_id: builtins.str
    """conversation id"""
    message_uid: builtins.str
    """message uid"""
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        app_id: builtins.str = ...,
        conversation_id: builtins.str = ...,
        message_uid: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_id", b"app_id", "conversation_id", b"conversation_id", "message_uid", b"message_uid", "namespace_id", b"namespace_id"]) -> None: ...

global___DeleteMessageRequest = DeleteMessageRequest

@typing_extensions.final
class DeleteMessageResponse(google.protobuf.message.Message):
    """DeleteMessageResponse is empty as no content needs to be returned"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteMessageResponse = DeleteMessageResponse

@typing_extensions.final
class ChatRequest(google.protobuf.message.Message):
    """ChatRequest represents a request to send a message
    to a chatbot synchronously and streams back the results.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    APP_ID_FIELD_NUMBER: builtins.int
    CATALOG_ID_FIELD_NUMBER: builtins.int
    CONVERSATION_UID_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    TOP_K_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """Namespace ID"""
    app_id: builtins.str
    """App ID"""
    catalog_id: builtins.str
    """Catalog ID"""
    conversation_uid: builtins.str
    """Conversation UID"""
    message: builtins.str
    """User message"""
    top_k: builtins.int
    """top k, defaults to 5"""
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        app_id: builtins.str = ...,
        catalog_id: builtins.str = ...,
        conversation_uid: builtins.str = ...,
        message: builtins.str = ...,
        top_k: builtins.int | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_top_k", b"_top_k", "top_k", b"top_k"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_top_k", b"_top_k", "app_id", b"app_id", "catalog_id", b"catalog_id", "conversation_uid", b"conversation_uid", "message", b"message", "namespace_id", b"namespace_id", "top_k", b"top_k"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_top_k", b"_top_k"]) -> typing_extensions.Literal["top_k"] | None: ...

global___ChatRequest = ChatRequest

@typing_extensions.final
class ChatResponse(google.protobuf.message.Message):
    """ChatResponse contains the chatbot response."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OUTPUTS_FIELD_NUMBER: builtins.int
    CHUNKS_FIELD_NUMBER: builtins.int
    @property
    def outputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.struct_pb2.Struct]:
        """Conversation responses."""
    @property
    def chunks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[artifact.artifact.v1alpha.chunk_pb2.SimilarityChunk]:
        """Reference chunks"""
    def __init__(
        self,
        *,
        outputs: collections.abc.Iterable[google.protobuf.struct_pb2.Struct] | None = ...,
        chunks: collections.abc.Iterable[artifact.artifact.v1alpha.chunk_pb2.SimilarityChunk] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["chunks", b"chunks", "outputs", b"outputs"]) -> None: ...

global___ChatResponse = ChatResponse



# pylint: disable=no-name-in-module
from instill.helpers.protobufs.ray_pb2 import CallRequest, CallResponse
from instill.helpers.ray_config import InstillDeployable, instill_deployment
from instill.helpers.ray_io import (
    construct_custom_output,
    construct_task_chat_output,
    construct_task_classification_output,
    construct_task_completion_output,
    construct_task_detection_output,
    construct_task_embedding_output,
    construct_task_instance_segmentation_output,
    construct_task_keypoint_output,
    construct_task_ocr_output,
    construct_task_semantic_segmentation_output,
    construct_task_text_to_image_output,
    parse_custom_input,
    parse_task_chat_to_chat_input,
    parse_task_chat_to_multimodal_chat_input,
    parse_task_classification_to_vision_input,
    parse_task_completion_to_completion_input,
    parse_task_detection_to_vision_input,
    parse_task_embedding_to_image_embedding_input,
    parse_task_embedding_to_multimodal_embedding_input,
    parse_task_embedding_to_text_embedding_input,
    parse_task_instance_segmentation_to_vision_input,
    parse_task_keypoint_to_vision_input,
    parse_task_ocr_to_vision_input,
    parse_task_semantic_segmentation_to_vision_input,
    parse_task_text_to_image_input,
)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import artifact.artifact.v1alpha.artifact_pb2
import artifact.artifact.v1alpha.chunk_pb2
import artifact.artifact.v1alpha.file_catalog_pb2
import artifact.artifact.v1alpha.object_pb2
import artifact.artifact.v1alpha.qa_pb2
import collections.abc
import grpc
import grpc.aio
import typing

_T = typing.TypeVar('_T')

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta):
    ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore
    ...

class ArtifactPublicServiceStub:
    """ArtifactPublicService exposes the public endpoints that allow clients to
    manage artifacts.
    """

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Liveness: grpc.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.artifact_pb2.LivenessRequest,
        artifact.artifact.v1alpha.artifact_pb2.LivenessResponse,
    ]
    """Check if the artifact server is alive

    See https://github.com/grpc/grpc/blob/master/doc/health-checking.md.
    """
    Readiness: grpc.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.artifact_pb2.ReadinessRequest,
        artifact.artifact.v1alpha.artifact_pb2.ReadinessResponse,
    ]
    """Check if the artifact server is ready

    See https://github.com/grpc/grpc/blob/master/doc/health-checking.md
    """
    CreateCatalog: grpc.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.artifact_pb2.CreateCatalogRequest,
        artifact.artifact.v1alpha.artifact_pb2.CreateCatalogResponse,
    ]
    """TODO improve public endpoint definitions with title and description.

    Create a catalog
    """
    ListCatalogs: grpc.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.artifact_pb2.ListCatalogsRequest,
        artifact.artifact.v1alpha.artifact_pb2.ListCatalogsResponse,
    ]
    """Get all catalogs info"""
    UpdateCatalog: grpc.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.artifact_pb2.UpdateCatalogRequest,
        artifact.artifact.v1alpha.artifact_pb2.UpdateCatalogResponse,
    ]
    """Update a catalog info"""
    DeleteCatalog: grpc.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.artifact_pb2.DeleteCatalogRequest,
        artifact.artifact.v1alpha.artifact_pb2.DeleteCatalogResponse,
    ]
    """Delete a catalog"""
    UploadCatalogFile: grpc.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.artifact_pb2.UploadCatalogFileRequest,
        artifact.artifact.v1alpha.artifact_pb2.UploadCatalogFileResponse,
    ]
    """Create a file"""
    DeleteCatalogFile: grpc.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.artifact_pb2.DeleteCatalogFileRequest,
        artifact.artifact.v1alpha.artifact_pb2.DeleteCatalogFileResponse,
    ]
    """Delete a file"""
    ProcessCatalogFiles: grpc.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.artifact_pb2.ProcessCatalogFilesRequest,
        artifact.artifact.v1alpha.artifact_pb2.ProcessCatalogFilesResponse,
    ]
    """Process catalog files"""
    ListCatalogFiles: grpc.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.artifact_pb2.ListCatalogFilesRequest,
        artifact.artifact.v1alpha.artifact_pb2.ListCatalogFilesResponse,
    ]
    """List catalog files"""
    ListChunks: grpc.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.chunk_pb2.ListChunksRequest,
        artifact.artifact.v1alpha.chunk_pb2.ListChunksResponse,
    ]
    """List catalog chunks"""
    GetSourceFile: grpc.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.chunk_pb2.GetSourceFileRequest,
        artifact.artifact.v1alpha.chunk_pb2.GetSourceFileResponse,
    ]
    """Get catalog single-source-of-truth file"""
    UpdateChunk: grpc.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.chunk_pb2.UpdateChunkRequest,
        artifact.artifact.v1alpha.chunk_pb2.UpdateChunkResponse,
    ]
    """Update catalog chunk"""
    SimilarityChunksSearch: grpc.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.chunk_pb2.SimilarityChunksSearchRequest,
        artifact.artifact.v1alpha.chunk_pb2.SimilarityChunksSearchResponse,
    ]
    """Retrieve similar chunks"""
    QuestionAnswering: grpc.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.qa_pb2.QuestionAnsweringRequest,
        artifact.artifact.v1alpha.qa_pb2.QuestionAnsweringResponse,
    ]
    """Ask a question"""
    GetFileCatalog: grpc.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.file_catalog_pb2.GetFileCatalogRequest,
        artifact.artifact.v1alpha.file_catalog_pb2.GetFileCatalogResponse,
    ]
    """Get file catalog"""
    ListCatalogRuns: grpc.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.artifact_pb2.ListCatalogRunsRequest,
        artifact.artifact.v1alpha.artifact_pb2.ListCatalogRunsResponse,
    ]
    """List Catalog Runs"""
    GetObjectUploadURL: grpc.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.object_pb2.GetObjectUploadURLRequest,
        artifact.artifact.v1alpha.object_pb2.GetObjectUploadURLResponse,
    ]
    """Get Object Upload URL"""
    GetObjectDownloadURL: grpc.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.object_pb2.GetObjectDownloadURLRequest,
        artifact.artifact.v1alpha.object_pb2.GetObjectDownloadURLResponse,
    ]
    """Get Object Download URL"""

class ArtifactPublicServiceAsyncStub:
    """ArtifactPublicService exposes the public endpoints that allow clients to
    manage artifacts.
    """

    Liveness: grpc.aio.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.artifact_pb2.LivenessRequest,
        artifact.artifact.v1alpha.artifact_pb2.LivenessResponse,
    ]
    """Check if the artifact server is alive

    See https://github.com/grpc/grpc/blob/master/doc/health-checking.md.
    """
    Readiness: grpc.aio.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.artifact_pb2.ReadinessRequest,
        artifact.artifact.v1alpha.artifact_pb2.ReadinessResponse,
    ]
    """Check if the artifact server is ready

    See https://github.com/grpc/grpc/blob/master/doc/health-checking.md
    """
    CreateCatalog: grpc.aio.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.artifact_pb2.CreateCatalogRequest,
        artifact.artifact.v1alpha.artifact_pb2.CreateCatalogResponse,
    ]
    """TODO improve public endpoint definitions with title and description.

    Create a catalog
    """
    ListCatalogs: grpc.aio.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.artifact_pb2.ListCatalogsRequest,
        artifact.artifact.v1alpha.artifact_pb2.ListCatalogsResponse,
    ]
    """Get all catalogs info"""
    UpdateCatalog: grpc.aio.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.artifact_pb2.UpdateCatalogRequest,
        artifact.artifact.v1alpha.artifact_pb2.UpdateCatalogResponse,
    ]
    """Update a catalog info"""
    DeleteCatalog: grpc.aio.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.artifact_pb2.DeleteCatalogRequest,
        artifact.artifact.v1alpha.artifact_pb2.DeleteCatalogResponse,
    ]
    """Delete a catalog"""
    UploadCatalogFile: grpc.aio.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.artifact_pb2.UploadCatalogFileRequest,
        artifact.artifact.v1alpha.artifact_pb2.UploadCatalogFileResponse,
    ]
    """Create a file"""
    DeleteCatalogFile: grpc.aio.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.artifact_pb2.DeleteCatalogFileRequest,
        artifact.artifact.v1alpha.artifact_pb2.DeleteCatalogFileResponse,
    ]
    """Delete a file"""
    ProcessCatalogFiles: grpc.aio.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.artifact_pb2.ProcessCatalogFilesRequest,
        artifact.artifact.v1alpha.artifact_pb2.ProcessCatalogFilesResponse,
    ]
    """Process catalog files"""
    ListCatalogFiles: grpc.aio.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.artifact_pb2.ListCatalogFilesRequest,
        artifact.artifact.v1alpha.artifact_pb2.ListCatalogFilesResponse,
    ]
    """List catalog files"""
    ListChunks: grpc.aio.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.chunk_pb2.ListChunksRequest,
        artifact.artifact.v1alpha.chunk_pb2.ListChunksResponse,
    ]
    """List catalog chunks"""
    GetSourceFile: grpc.aio.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.chunk_pb2.GetSourceFileRequest,
        artifact.artifact.v1alpha.chunk_pb2.GetSourceFileResponse,
    ]
    """Get catalog single-source-of-truth file"""
    UpdateChunk: grpc.aio.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.chunk_pb2.UpdateChunkRequest,
        artifact.artifact.v1alpha.chunk_pb2.UpdateChunkResponse,
    ]
    """Update catalog chunk"""
    SimilarityChunksSearch: grpc.aio.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.chunk_pb2.SimilarityChunksSearchRequest,
        artifact.artifact.v1alpha.chunk_pb2.SimilarityChunksSearchResponse,
    ]
    """Retrieve similar chunks"""
    QuestionAnswering: grpc.aio.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.qa_pb2.QuestionAnsweringRequest,
        artifact.artifact.v1alpha.qa_pb2.QuestionAnsweringResponse,
    ]
    """Ask a question"""
    GetFileCatalog: grpc.aio.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.file_catalog_pb2.GetFileCatalogRequest,
        artifact.artifact.v1alpha.file_catalog_pb2.GetFileCatalogResponse,
    ]
    """Get file catalog"""
    ListCatalogRuns: grpc.aio.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.artifact_pb2.ListCatalogRunsRequest,
        artifact.artifact.v1alpha.artifact_pb2.ListCatalogRunsResponse,
    ]
    """List Catalog Runs"""
    GetObjectUploadURL: grpc.aio.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.object_pb2.GetObjectUploadURLRequest,
        artifact.artifact.v1alpha.object_pb2.GetObjectUploadURLResponse,
    ]
    """Get Object Upload URL"""
    GetObjectDownloadURL: grpc.aio.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.object_pb2.GetObjectDownloadURLRequest,
        artifact.artifact.v1alpha.object_pb2.GetObjectDownloadURLResponse,
    ]
    """Get Object Download URL"""

class ArtifactPublicServiceServicer(metaclass=abc.ABCMeta):
    """ArtifactPublicService exposes the public endpoints that allow clients to
    manage artifacts.
    """

    @abc.abstractmethod
    def Liveness(
        self,
        request: artifact.artifact.v1alpha.artifact_pb2.LivenessRequest,
        context: _ServicerContext,
    ) -> typing.Union[artifact.artifact.v1alpha.artifact_pb2.LivenessResponse, collections.abc.Awaitable[artifact.artifact.v1alpha.artifact_pb2.LivenessResponse]]:
        """Check if the artifact server is alive

        See https://github.com/grpc/grpc/blob/master/doc/health-checking.md.
        """
    @abc.abstractmethod
    def Readiness(
        self,
        request: artifact.artifact.v1alpha.artifact_pb2.ReadinessRequest,
        context: _ServicerContext,
    ) -> typing.Union[artifact.artifact.v1alpha.artifact_pb2.ReadinessResponse, collections.abc.Awaitable[artifact.artifact.v1alpha.artifact_pb2.ReadinessResponse]]:
        """Check if the artifact server is ready

        See https://github.com/grpc/grpc/blob/master/doc/health-checking.md
        """
    @abc.abstractmethod
    def CreateCatalog(
        self,
        request: artifact.artifact.v1alpha.artifact_pb2.CreateCatalogRequest,
        context: _ServicerContext,
    ) -> typing.Union[artifact.artifact.v1alpha.artifact_pb2.CreateCatalogResponse, collections.abc.Awaitable[artifact.artifact.v1alpha.artifact_pb2.CreateCatalogResponse]]:
        """TODO improve public endpoint definitions with title and description.

        Create a catalog
        """
    @abc.abstractmethod
    def ListCatalogs(
        self,
        request: artifact.artifact.v1alpha.artifact_pb2.ListCatalogsRequest,
        context: _ServicerContext,
    ) -> typing.Union[artifact.artifact.v1alpha.artifact_pb2.ListCatalogsResponse, collections.abc.Awaitable[artifact.artifact.v1alpha.artifact_pb2.ListCatalogsResponse]]:
        """Get all catalogs info"""
    @abc.abstractmethod
    def UpdateCatalog(
        self,
        request: artifact.artifact.v1alpha.artifact_pb2.UpdateCatalogRequest,
        context: _ServicerContext,
    ) -> typing.Union[artifact.artifact.v1alpha.artifact_pb2.UpdateCatalogResponse, collections.abc.Awaitable[artifact.artifact.v1alpha.artifact_pb2.UpdateCatalogResponse]]:
        """Update a catalog info"""
    @abc.abstractmethod
    def DeleteCatalog(
        self,
        request: artifact.artifact.v1alpha.artifact_pb2.DeleteCatalogRequest,
        context: _ServicerContext,
    ) -> typing.Union[artifact.artifact.v1alpha.artifact_pb2.DeleteCatalogResponse, collections.abc.Awaitable[artifact.artifact.v1alpha.artifact_pb2.DeleteCatalogResponse]]:
        """Delete a catalog"""
    @abc.abstractmethod
    def UploadCatalogFile(
        self,
        request: artifact.artifact.v1alpha.artifact_pb2.UploadCatalogFileRequest,
        context: _ServicerContext,
    ) -> typing.Union[artifact.artifact.v1alpha.artifact_pb2.UploadCatalogFileResponse, collections.abc.Awaitable[artifact.artifact.v1alpha.artifact_pb2.UploadCatalogFileResponse]]:
        """Create a file"""
    @abc.abstractmethod
    def DeleteCatalogFile(
        self,
        request: artifact.artifact.v1alpha.artifact_pb2.DeleteCatalogFileRequest,
        context: _ServicerContext,
    ) -> typing.Union[artifact.artifact.v1alpha.artifact_pb2.DeleteCatalogFileResponse, collections.abc.Awaitable[artifact.artifact.v1alpha.artifact_pb2.DeleteCatalogFileResponse]]:
        """Delete a file"""
    @abc.abstractmethod
    def ProcessCatalogFiles(
        self,
        request: artifact.artifact.v1alpha.artifact_pb2.ProcessCatalogFilesRequest,
        context: _ServicerContext,
    ) -> typing.Union[artifact.artifact.v1alpha.artifact_pb2.ProcessCatalogFilesResponse, collections.abc.Awaitable[artifact.artifact.v1alpha.artifact_pb2.ProcessCatalogFilesResponse]]:
        """Process catalog files"""
    @abc.abstractmethod
    def ListCatalogFiles(
        self,
        request: artifact.artifact.v1alpha.artifact_pb2.ListCatalogFilesRequest,
        context: _ServicerContext,
    ) -> typing.Union[artifact.artifact.v1alpha.artifact_pb2.ListCatalogFilesResponse, collections.abc.Awaitable[artifact.artifact.v1alpha.artifact_pb2.ListCatalogFilesResponse]]:
        """List catalog files"""
    @abc.abstractmethod
    def ListChunks(
        self,
        request: artifact.artifact.v1alpha.chunk_pb2.ListChunksRequest,
        context: _ServicerContext,
    ) -> typing.Union[artifact.artifact.v1alpha.chunk_pb2.ListChunksResponse, collections.abc.Awaitable[artifact.artifact.v1alpha.chunk_pb2.ListChunksResponse]]:
        """List catalog chunks"""
    @abc.abstractmethod
    def GetSourceFile(
        self,
        request: artifact.artifact.v1alpha.chunk_pb2.GetSourceFileRequest,
        context: _ServicerContext,
    ) -> typing.Union[artifact.artifact.v1alpha.chunk_pb2.GetSourceFileResponse, collections.abc.Awaitable[artifact.artifact.v1alpha.chunk_pb2.GetSourceFileResponse]]:
        """Get catalog single-source-of-truth file"""
    @abc.abstractmethod
    def UpdateChunk(
        self,
        request: artifact.artifact.v1alpha.chunk_pb2.UpdateChunkRequest,
        context: _ServicerContext,
    ) -> typing.Union[artifact.artifact.v1alpha.chunk_pb2.UpdateChunkResponse, collections.abc.Awaitable[artifact.artifact.v1alpha.chunk_pb2.UpdateChunkResponse]]:
        """Update catalog chunk"""
    @abc.abstractmethod
    def SimilarityChunksSearch(
        self,
        request: artifact.artifact.v1alpha.chunk_pb2.SimilarityChunksSearchRequest,
        context: _ServicerContext,
    ) -> typing.Union[artifact.artifact.v1alpha.chunk_pb2.SimilarityChunksSearchResponse, collections.abc.Awaitable[artifact.artifact.v1alpha.chunk_pb2.SimilarityChunksSearchResponse]]:
        """Retrieve similar chunks"""
    @abc.abstractmethod
    def QuestionAnswering(
        self,
        request: artifact.artifact.v1alpha.qa_pb2.QuestionAnsweringRequest,
        context: _ServicerContext,
    ) -> typing.Union[artifact.artifact.v1alpha.qa_pb2.QuestionAnsweringResponse, collections.abc.Awaitable[artifact.artifact.v1alpha.qa_pb2.QuestionAnsweringResponse]]:
        """Ask a question"""
    @abc.abstractmethod
    def GetFileCatalog(
        self,
        request: artifact.artifact.v1alpha.file_catalog_pb2.GetFileCatalogRequest,
        context: _ServicerContext,
    ) -> typing.Union[artifact.artifact.v1alpha.file_catalog_pb2.GetFileCatalogResponse, collections.abc.Awaitable[artifact.artifact.v1alpha.file_catalog_pb2.GetFileCatalogResponse]]:
        """Get file catalog"""
    @abc.abstractmethod
    def ListCatalogRuns(
        self,
        request: artifact.artifact.v1alpha.artifact_pb2.ListCatalogRunsRequest,
        context: _ServicerContext,
    ) -> typing.Union[artifact.artifact.v1alpha.artifact_pb2.ListCatalogRunsResponse, collections.abc.Awaitable[artifact.artifact.v1alpha.artifact_pb2.ListCatalogRunsResponse]]:
        """List Catalog Runs"""
    @abc.abstractmethod
    def GetObjectUploadURL(
        self,
        request: artifact.artifact.v1alpha.object_pb2.GetObjectUploadURLRequest,
        context: _ServicerContext,
    ) -> typing.Union[artifact.artifact.v1alpha.object_pb2.GetObjectUploadURLResponse, collections.abc.Awaitable[artifact.artifact.v1alpha.object_pb2.GetObjectUploadURLResponse]]:
        """Get Object Upload URL"""
    @abc.abstractmethod
    def GetObjectDownloadURL(
        self,
        request: artifact.artifact.v1alpha.object_pb2.GetObjectDownloadURLRequest,
        context: _ServicerContext,
    ) -> typing.Union[artifact.artifact.v1alpha.object_pb2.GetObjectDownloadURLResponse, collections.abc.Awaitable[artifact.artifact.v1alpha.object_pb2.GetObjectDownloadURLResponse]]:
        """Get Object Download URL"""

def add_ArtifactPublicServiceServicer_to_server(servicer: ArtifactPublicServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vdp/pipeline/v1beta/secret.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n vdp/pipeline/v1beta/secret.proto\x12\x13vdp.pipeline.v1beta\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a.protoc-gen-openapiv2/options/annotations.proto\"\x9a\x03\n\x06Secret\x12\x17\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x04name\x12\x15\n\x03uid\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x03uid\x12\x13\n\x02id\x18\x03 \x01(\tB\x03\xe0\x41\x05R\x02id\x12@\n\x0b\x63reate_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x12@\n\x0bupdate_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\nupdateTime\x12\x1e\n\x05value\x18\x06 \x01(\tB\x03\xe0\x41\x04H\x00R\x05value\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x07 \x01(\tB\x03\xe0\x41\x01R\x0b\x64\x65scription:v\xea\x41s\n\x17\x61pi.instill.tech/Secret\x12#users/{user.id}/secrets/{secret.id}\x12\x33organizations/{organization.id}/secrets/{secret.id}B\x08\n\x06_value\"{\n\x1c\x43reateNamespaceSecretRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12\x33\n\x06secret\x18\x02 \x01(\x0b\x32\x1b.vdp.pipeline.v1beta.SecretR\x06secret\"Y\n\x1d\x43reateNamespaceSecretResponse\x12\x38\n\x06secret\x18\x01 \x01(\x0b\x32\x1b.vdp.pipeline.v1beta.SecretB\x03\xe0\x41\x03R\x06secret\"\xb2\x01\n\x1bListNamespaceSecretsRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12%\n\tpage_size\x18\x02 \x01(\x05\x42\x03\xe0\x41\x01H\x00R\x08pageSize\x88\x01\x01\x12\'\n\npage_token\x18\x03 \x01(\tB\x03\xe0\x41\x01H\x01R\tpageToken\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_token\"\xab\x01\n\x1cListNamespaceSecretsResponse\x12:\n\x07secrets\x18\x01 \x03(\x0b\x32\x1b.vdp.pipeline.v1beta.SecretB\x03\xe0\x41\x03R\x07secrets\x12+\n\x0fnext_page_token\x18\x02 \x01(\tB\x03\xe0\x41\x03R\rnextPageToken\x12\"\n\ntotal_size\x18\x03 \x01(\x05\x42\x03\xe0\x41\x03R\ttotalSize\"e\n\x19GetNamespaceSecretRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12 \n\tsecret_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x08secretId\"Q\n\x1aGetNamespaceSecretResponse\x12\x33\n\x06secret\x18\x01 \x01(\x0b\x32\x1b.vdp.pipeline.v1beta.SecretR\x06secret\"\xdf\x01\n\x1cUpdateNamespaceSecretRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12 \n\tsecret_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x08secretId\x12\x33\n\x06secret\x18\x03 \x01(\x0b\x32\x1b.vdp.pipeline.v1beta.SecretR\x06secret\x12@\n\x0bupdate_mask\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x03\xe0\x41\x02R\nupdateMask\"T\n\x1dUpdateNamespaceSecretResponse\x12\x33\n\x06secret\x18\x01 \x01(\x0b\x32\x1b.vdp.pipeline.v1beta.SecretR\x06secret\"h\n\x1c\x44\x65leteNamespaceSecretRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12 \n\tsecret_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x08secretId\"\x1f\n\x1d\x44\x65leteNamespaceSecretResponse\"\x99\x01\n\x17\x43reateUserSecretRequest\x12\x33\n\x06secret\x18\x01 \x01(\x0b\x32\x1b.vdp.pipeline.v1beta.SecretR\x06secret\x12I\n\x06parent\x18\x02 \x01(\tB1\x92\x41\x0f\xca>\x0c\xfa\x02\tuser_name\xe0\x41\x02\xfa\x41\x19\x12\x17\x61pi.instill.tech/SecretR\x06parent\"O\n\x18\x43reateUserSecretResponse\x12\x33\n\x06secret\x18\x01 \x01(\x0b\x32\x1b.vdp.pipeline.v1beta.SecretR\x06secret\"\xd0\x01\n\x16ListUserSecretsRequest\x12%\n\tpage_size\x18\x01 \x01(\x05\x42\x03\xe0\x41\x01H\x00R\x08pageSize\x88\x01\x01\x12\'\n\npage_token\x18\x02 \x01(\tB\x03\xe0\x41\x01H\x01R\tpageToken\x88\x01\x01\x12I\n\x06parent\x18\x03 \x01(\tB1\x92\x41\x0f\xca>\x0c\xfa\x02\tuser_name\xe0\x41\x02\xfa\x41\x19\x12\x17\x61pi.instill.tech/SecretR\x06parentB\x0c\n\n_page_sizeB\r\n\x0b_page_token\"\x97\x01\n\x17ListUserSecretsResponse\x12\x35\n\x07secrets\x18\x01 \x03(\x0b\x32\x1b.vdp.pipeline.v1beta.SecretR\x07secrets\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1d\n\ntotal_size\x18\x03 \x01(\x05R\ttotalSize\"d\n\x14GetUserSecretRequest\x12L\n\x04name\x18\x01 \x01(\tB8\x92\x41\x16\xca>\x13\xfa\x02\x10user_secret_name\xe0\x41\x02\xfa\x41\x19\n\x17\x61pi.instill.tech/SecretR\x04name\"L\n\x15GetUserSecretResponse\x12\x33\n\x06secret\x18\x01 \x01(\x0b\x32\x1b.vdp.pipeline.v1beta.SecretR\x06secret\"\x95\x01\n\x17UpdateUserSecretRequest\x12\x38\n\x06secret\x18\x01 \x01(\x0b\x32\x1b.vdp.pipeline.v1beta.SecretB\x03\xe0\x41\x02R\x06secret\x12@\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x03\xe0\x41\x02R\nupdateMask\"O\n\x18UpdateUserSecretResponse\x12\x33\n\x06secret\x18\x01 \x01(\x0b\x32\x1b.vdp.pipeline.v1beta.SecretR\x06secret\"g\n\x17\x44\x65leteUserSecretRequest\x12L\n\x04name\x18\x01 \x01(\tB8\x92\x41\x16\xca>\x13\xfa\x02\x10user_secret_name\xe0\x41\x02\xfa\x41\x19\n\x17\x61pi.instill.tech/SecretR\x04name\"\x1a\n\x18\x44\x65leteUserSecretResponse\"\xa9\x01\n\x1f\x43reateOrganizationSecretRequest\x12\x33\n\x06secret\x18\x01 \x01(\x0b\x32\x1b.vdp.pipeline.v1beta.SecretR\x06secret\x12Q\n\x06parent\x18\x02 \x01(\tB9\x92\x41\x17\xca>\x14\xfa\x02\x11organization_name\xe0\x41\x02\xfa\x41\x19\x12\x17\x61pi.instill.tech/SecretR\x06parent\"W\n CreateOrganizationSecretResponse\x12\x33\n\x06secret\x18\x01 \x01(\x0b\x32\x1b.vdp.pipeline.v1beta.SecretR\x06secret\"\xe0\x01\n\x1eListOrganizationSecretsRequest\x12%\n\tpage_size\x18\x01 \x01(\x05\x42\x03\xe0\x41\x01H\x00R\x08pageSize\x88\x01\x01\x12\'\n\npage_token\x18\x02 \x01(\tB\x03\xe0\x41\x01H\x01R\tpageToken\x88\x01\x01\x12Q\n\x06parent\x18\x03 \x01(\tB9\x92\x41\x17\xca>\x14\xfa\x02\x11organization_name\xe0\x41\x02\xfa\x41\x19\x12\x17\x61pi.instill.tech/SecretR\x06parentB\x0c\n\n_page_sizeB\r\n\x0b_page_token\"\x9f\x01\n\x1fListOrganizationSecretsResponse\x12\x35\n\x07secrets\x18\x01 \x03(\x0b\x32\x1b.vdp.pipeline.v1beta.SecretR\x07secrets\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1d\n\ntotal_size\x18\x03 \x01(\x05R\ttotalSize\"t\n\x1cGetOrganizationSecretRequest\x12T\n\x04name\x18\x01 \x01(\tB@\x92\x41\x1e\xca>\x1b\xfa\x02\x18organization_secret_name\xe0\x41\x02\xfa\x41\x19\n\x17\x61pi.instill.tech/SecretR\x04name\"T\n\x1dGetOrganizationSecretResponse\x12\x33\n\x06secret\x18\x01 \x01(\x0b\x32\x1b.vdp.pipeline.v1beta.SecretR\x06secret\"\x9d\x01\n\x1fUpdateOrganizationSecretRequest\x12\x38\n\x06secret\x18\x01 \x01(\x0b\x32\x1b.vdp.pipeline.v1beta.SecretB\x03\xe0\x41\x02R\x06secret\x12@\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x03\xe0\x41\x02R\nupdateMask\"W\n UpdateOrganizationSecretResponse\x12\x33\n\x06secret\x18\x01 \x01(\x0b\x32\x1b.vdp.pipeline.v1beta.SecretR\x06secret\"w\n\x1f\x44\x65leteOrganizationSecretRequest\x12T\n\x04name\x18\x01 \x01(\tB@\x92\x41\x1e\xca>\x1b\xfa\x02\x18organization_secret_name\xe0\x41\x02\xfa\x41\x19\n\x17\x61pi.instill.tech/SecretR\x04name\"\"\n DeleteOrganizationSecretResponseB\xda\x01\n\x17\x63om.vdp.pipeline.v1betaB\x0bSecretProtoP\x01ZDgithub.com/instill-ai/protogen-go/vdp/pipeline/v1beta;pipelinev1beta\xa2\x02\x03VPX\xaa\x02\x13Vdp.Pipeline.V1beta\xca\x02\x13Vdp\\Pipeline\\V1beta\xe2\x02\x1fVdp\\Pipeline\\V1beta\\GPBMetadata\xea\x02\x15Vdp::Pipeline::V1betab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vdp.pipeline.v1beta.secret_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.vdp.pipeline.v1betaB\013SecretProtoP\001ZDgithub.com/instill-ai/protogen-go/vdp/pipeline/v1beta;pipelinev1beta\242\002\003VPX\252\002\023Vdp.Pipeline.V1beta\312\002\023Vdp\\Pipeline\\V1beta\342\002\037Vdp\\Pipeline\\V1beta\\GPBMetadata\352\002\025Vdp::Pipeline::V1beta'
  _SECRET.fields_by_name['name']._options = None
  _SECRET.fields_by_name['name']._serialized_options = b'\340A\003'
  _SECRET.fields_by_name['uid']._options = None
  _SECRET.fields_by_name['uid']._serialized_options = b'\340A\003'
  _SECRET.fields_by_name['id']._options = None
  _SECRET.fields_by_name['id']._serialized_options = b'\340A\005'
  _SECRET.fields_by_name['create_time']._options = None
  _SECRET.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _SECRET.fields_by_name['update_time']._options = None
  _SECRET.fields_by_name['update_time']._serialized_options = b'\340A\003'
  _SECRET.fields_by_name['value']._options = None
  _SECRET.fields_by_name['value']._serialized_options = b'\340A\004'
  _SECRET.fields_by_name['description']._options = None
  _SECRET.fields_by_name['description']._serialized_options = b'\340A\001'
  _SECRET._options = None
  _SECRET._serialized_options = b'\352As\n\027api.instill.tech/Secret\022#users/{user.id}/secrets/{secret.id}\0223organizations/{organization.id}/secrets/{secret.id}'
  _CREATENAMESPACESECRETREQUEST.fields_by_name['namespace_id']._options = None
  _CREATENAMESPACESECRETREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _CREATENAMESPACESECRETRESPONSE.fields_by_name['secret']._options = None
  _CREATENAMESPACESECRETRESPONSE.fields_by_name['secret']._serialized_options = b'\340A\003'
  _LISTNAMESPACESECRETSREQUEST.fields_by_name['namespace_id']._options = None
  _LISTNAMESPACESECRETSREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _LISTNAMESPACESECRETSREQUEST.fields_by_name['page_size']._options = None
  _LISTNAMESPACESECRETSREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTNAMESPACESECRETSREQUEST.fields_by_name['page_token']._options = None
  _LISTNAMESPACESECRETSREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\001'
  _LISTNAMESPACESECRETSRESPONSE.fields_by_name['secrets']._options = None
  _LISTNAMESPACESECRETSRESPONSE.fields_by_name['secrets']._serialized_options = b'\340A\003'
  _LISTNAMESPACESECRETSRESPONSE.fields_by_name['next_page_token']._options = None
  _LISTNAMESPACESECRETSRESPONSE.fields_by_name['next_page_token']._serialized_options = b'\340A\003'
  _LISTNAMESPACESECRETSRESPONSE.fields_by_name['total_size']._options = None
  _LISTNAMESPACESECRETSRESPONSE.fields_by_name['total_size']._serialized_options = b'\340A\003'
  _GETNAMESPACESECRETREQUEST.fields_by_name['namespace_id']._options = None
  _GETNAMESPACESECRETREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _GETNAMESPACESECRETREQUEST.fields_by_name['secret_id']._options = None
  _GETNAMESPACESECRETREQUEST.fields_by_name['secret_id']._serialized_options = b'\340A\002'
  _UPDATENAMESPACESECRETREQUEST.fields_by_name['namespace_id']._options = None
  _UPDATENAMESPACESECRETREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _UPDATENAMESPACESECRETREQUEST.fields_by_name['secret_id']._options = None
  _UPDATENAMESPACESECRETREQUEST.fields_by_name['secret_id']._serialized_options = b'\340A\002'
  _UPDATENAMESPACESECRETREQUEST.fields_by_name['update_mask']._options = None
  _UPDATENAMESPACESECRETREQUEST.fields_by_name['update_mask']._serialized_options = b'\340A\002'
  _DELETENAMESPACESECRETREQUEST.fields_by_name['namespace_id']._options = None
  _DELETENAMESPACESECRETREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _DELETENAMESPACESECRETREQUEST.fields_by_name['secret_id']._options = None
  _DELETENAMESPACESECRETREQUEST.fields_by_name['secret_id']._serialized_options = b'\340A\002'
  _CREATEUSERSECRETREQUEST.fields_by_name['parent']._options = None
  _CREATEUSERSECRETREQUEST.fields_by_name['parent']._serialized_options = b'\222A\017\312>\014\372\002\tuser_name\340A\002\372A\031\022\027api.instill.tech/Secret'
  _LISTUSERSECRETSREQUEST.fields_by_name['page_size']._options = None
  _LISTUSERSECRETSREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTUSERSECRETSREQUEST.fields_by_name['page_token']._options = None
  _LISTUSERSECRETSREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\001'
  _LISTUSERSECRETSREQUEST.fields_by_name['parent']._options = None
  _LISTUSERSECRETSREQUEST.fields_by_name['parent']._serialized_options = b'\222A\017\312>\014\372\002\tuser_name\340A\002\372A\031\022\027api.instill.tech/Secret'
  _GETUSERSECRETREQUEST.fields_by_name['name']._options = None
  _GETUSERSECRETREQUEST.fields_by_name['name']._serialized_options = b'\222A\026\312>\023\372\002\020user_secret_name\340A\002\372A\031\n\027api.instill.tech/Secret'
  _UPDATEUSERSECRETREQUEST.fields_by_name['secret']._options = None
  _UPDATEUSERSECRETREQUEST.fields_by_name['secret']._serialized_options = b'\340A\002'
  _UPDATEUSERSECRETREQUEST.fields_by_name['update_mask']._options = None
  _UPDATEUSERSECRETREQUEST.fields_by_name['update_mask']._serialized_options = b'\340A\002'
  _DELETEUSERSECRETREQUEST.fields_by_name['name']._options = None
  _DELETEUSERSECRETREQUEST.fields_by_name['name']._serialized_options = b'\222A\026\312>\023\372\002\020user_secret_name\340A\002\372A\031\n\027api.instill.tech/Secret'
  _CREATEORGANIZATIONSECRETREQUEST.fields_by_name['parent']._options = None
  _CREATEORGANIZATIONSECRETREQUEST.fields_by_name['parent']._serialized_options = b'\222A\027\312>\024\372\002\021organization_name\340A\002\372A\031\022\027api.instill.tech/Secret'
  _LISTORGANIZATIONSECRETSREQUEST.fields_by_name['page_size']._options = None
  _LISTORGANIZATIONSECRETSREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTORGANIZATIONSECRETSREQUEST.fields_by_name['page_token']._options = None
  _LISTORGANIZATIONSECRETSREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\001'
  _LISTORGANIZATIONSECRETSREQUEST.fields_by_name['parent']._options = None
  _LISTORGANIZATIONSECRETSREQUEST.fields_by_name['parent']._serialized_options = b'\222A\027\312>\024\372\002\021organization_name\340A\002\372A\031\022\027api.instill.tech/Secret'
  _GETORGANIZATIONSECRETREQUEST.fields_by_name['name']._options = None
  _GETORGANIZATIONSECRETREQUEST.fields_by_name['name']._serialized_options = b'\222A\036\312>\033\372\002\030organization_secret_name\340A\002\372A\031\n\027api.instill.tech/Secret'
  _UPDATEORGANIZATIONSECRETREQUEST.fields_by_name['secret']._options = None
  _UPDATEORGANIZATIONSECRETREQUEST.fields_by_name['secret']._serialized_options = b'\340A\002'
  _UPDATEORGANIZATIONSECRETREQUEST.fields_by_name['update_mask']._options = None
  _UPDATEORGANIZATIONSECRETREQUEST.fields_by_name['update_mask']._serialized_options = b'\340A\002'
  _DELETEORGANIZATIONSECRETREQUEST.fields_by_name['name']._options = None
  _DELETEORGANIZATIONSECRETREQUEST.fields_by_name['name']._serialized_options = b'\222A\036\312>\033\372\002\030organization_secret_name\340A\002\372A\031\n\027api.instill.tech/Secret'
  _globals['_SECRET']._serialized_start=233
  _globals['_SECRET']._serialized_end=643
  _globals['_CREATENAMESPACESECRETREQUEST']._serialized_start=645
  _globals['_CREATENAMESPACESECRETREQUEST']._serialized_end=768
  _globals['_CREATENAMESPACESECRETRESPONSE']._serialized_start=770
  _globals['_CREATENAMESPACESECRETRESPONSE']._serialized_end=859
  _globals['_LISTNAMESPACESECRETSREQUEST']._serialized_start=862
  _globals['_LISTNAMESPACESECRETSREQUEST']._serialized_end=1040
  _globals['_LISTNAMESPACESECRETSRESPONSE']._serialized_start=1043
  _globals['_LISTNAMESPACESECRETSRESPONSE']._serialized_end=1214
  _globals['_GETNAMESPACESECRETREQUEST']._serialized_start=1216
  _globals['_GETNAMESPACESECRETREQUEST']._serialized_end=1317
  _globals['_GETNAMESPACESECRETRESPONSE']._serialized_start=1319
  _globals['_GETNAMESPACESECRETRESPONSE']._serialized_end=1400
  _globals['_UPDATENAMESPACESECRETREQUEST']._serialized_start=1403
  _globals['_UPDATENAMESPACESECRETREQUEST']._serialized_end=1626
  _globals['_UPDATENAMESPACESECRETRESPONSE']._serialized_start=1628
  _globals['_UPDATENAMESPACESECRETRESPONSE']._serialized_end=1712
  _globals['_DELETENAMESPACESECRETREQUEST']._serialized_start=1714
  _globals['_DELETENAMESPACESECRETREQUEST']._serialized_end=1818
  _globals['_DELETENAMESPACESECRETRESPONSE']._serialized_start=1820
  _globals['_DELETENAMESPACESECRETRESPONSE']._serialized_end=1851
  _globals['_CREATEUSERSECRETREQUEST']._serialized_start=1854
  _globals['_CREATEUSERSECRETREQUEST']._serialized_end=2007
  _globals['_CREATEUSERSECRETRESPONSE']._serialized_start=2009
  _globals['_CREATEUSERSECRETRESPONSE']._serialized_end=2088
  _globals['_LISTUSERSECRETSREQUEST']._serialized_start=2091
  _globals['_LISTUSERSECRETSREQUEST']._serialized_end=2299
  _globals['_LISTUSERSECRETSRESPONSE']._serialized_start=2302
  _globals['_LISTUSERSECRETSRESPONSE']._serialized_end=2453
  _globals['_GETUSERSECRETREQUEST']._serialized_start=2455
  _globals['_GETUSERSECRETREQUEST']._serialized_end=2555
  _globals['_GETUSERSECRETRESPONSE']._serialized_start=2557
  _globals['_GETUSERSECRETRESPONSE']._serialized_end=2633
  _globals['_UPDATEUSERSECRETREQUEST']._serialized_start=2636
  _globals['_UPDATEUSERSECRETREQUEST']._serialized_end=2785
  _globals['_UPDATEUSERSECRETRESPONSE']._serialized_start=2787
  _globals['_UPDATEUSERSECRETRESPONSE']._serialized_end=2866
  _globals['_DELETEUSERSECRETREQUEST']._serialized_start=2868
  _globals['_DELETEUSERSECRETREQUEST']._serialized_end=2971
  _globals['_DELETEUSERSECRETRESPONSE']._serialized_start=2973
  _globals['_DELETEUSERSECRETRESPONSE']._serialized_end=2999
  _globals['_CREATEORGANIZATIONSECRETREQUEST']._serialized_start=3002
  _globals['_CREATEORGANIZATIONSECRETREQUEST']._serialized_end=3171
  _globals['_CREATEORGANIZATIONSECRETRESPONSE']._serialized_start=3173
  _globals['_CREATEORGANIZATIONSECRETRESPONSE']._serialized_end=3260
  _globals['_LISTORGANIZATIONSECRETSREQUEST']._serialized_start=3263
  _globals['_LISTORGANIZATIONSECRETSREQUEST']._serialized_end=3487
  _globals['_LISTORGANIZATIONSECRETSRESPONSE']._serialized_start=3490
  _globals['_LISTORGANIZATIONSECRETSRESPONSE']._serialized_end=3649
  _globals['_GETORGANIZATIONSECRETREQUEST']._serialized_start=3651
  _globals['_GETORGANIZATIONSECRETREQUEST']._serialized_end=3767
  _globals['_GETORGANIZATIONSECRETRESPONSE']._serialized_start=3769
  _globals['_GETORGANIZATIONSECRETRESPONSE']._serialized_end=3853
  _globals['_UPDATEORGANIZATIONSECRETREQUEST']._serialized_start=3856
  _globals['_UPDATEORGANIZATIONSECRETREQUEST']._serialized_end=4013
  _globals['_UPDATEORGANIZATIONSECRETRESPONSE']._serialized_start=4015
  _globals['_UPDATEORGANIZATIONSECRETRESPONSE']._serialized_end=4102
  _globals['_DELETEORGANIZATIONSECRETREQUEST']._serialized_start=4104
  _globals['_DELETEORGANIZATIONSECRETREQUEST']._serialized_end=4223
  _globals['_DELETEORGANIZATIONSECRETRESPONSE']._serialized_start=4225
  _globals['_DELETEORGANIZATIONSECRETRESPONSE']._serialized_end=4259
# @@protoc_insertion_point(module_scope)



# pylint: disable=no-member,wrong-import-position,too-many-lines,no-name-in-module
from datetime import datetime
from typing import Callable, List, Optional

# common
from google.protobuf import timestamp_pb2

# artifact
import instill.protogen.artifact.artifact.v1alpha.artifact_pb2 as artifact_interface
import instill.protogen.artifact.artifact.v1alpha.artifact_public_service_pb2_grpc as artifact_service
import instill.protogen.artifact.artifact.v1alpha.chunk_pb2 as chunk_interface
import instill.protogen.artifact.artifact.v1alpha.file_catalog_pb2 as file_catalog_interface
import instill.protogen.artifact.artifact.v1alpha.object_pb2 as object_interface
import instill.protogen.artifact.artifact.v1alpha.qa_pb2 as qa_interface
import instill.protogen.common.healthcheck.v1beta.healthcheck_pb2 as healthcheck
from instill.clients.base import Client, RequestFactory
from instill.clients.instance import InstillInstance
from instill.helpers.const import HOST_URL_PROD
from instill.utils.error_handler import grpc_handler
from instill.utils.process_file import process_file


class ArtifactClient(Client):
    def __init__(
        self,
        api_token: str,
        lookup_func: Callable[[str], str],
        url: str = HOST_URL_PROD,
        secure: bool = True,
        requester_id: str = "",
        async_enabled: bool = False,
    ) -> None:
        self.host: InstillInstance = InstillInstance(
            artifact_service.ArtifactPublicServiceStub,
            url=url,
            token=api_token,
            secure=secure,
            async_enabled=async_enabled,
        )
        self.metadata = []
        self._lookup_uid = lookup_func

        if requester_id != "":
            requester_uid = lookup_func(requester_id)
            self.metadata = [("instill-requester-uid", requester_uid)]

    def close(self):
        if self.is_serving():
            self.host.channel.close()

    async def async_close(self):
        if self.is_serving():
            self.host.channel.close()

    @property
    def host(self):
        return self._host

    @host.setter
    def host(self, host: InstillInstance):
        self._host = host

    @property
    def metadata(self):
        return self._metadata

    @metadata.setter
    def metadata(self, metadata: List[tuple]):
        self._metadata = metadata

    def liveness(
        self,
        async_enabled: bool = False,
    ) -> artifact_interface.LivenessResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.Liveness,
                request=artifact_interface.LivenessRequest(),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.Liveness,
            request=artifact_interface.LivenessRequest(),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    def readiness(
        self,
        async_enabled: bool = False,
    ) -> artifact_interface.ReadinessResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.Readiness,
                request=artifact_interface.ReadinessRequest(),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.Readiness,
            request=artifact_interface.ReadinessRequest(),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    def is_serving(self) -> bool:
        try:
            return (
                self.readiness().health_check_response.status
                == healthcheck.HealthCheckResponse.SERVING_STATUS_SERVING
            )
        except Exception:
            return False

    @grpc_handler
    def create_catalog(
        self,
        namespace_id: str,
        name: str,
        description: str,
        tags: Optional[list[str]] = None,
        async_enabled: bool = False,
    ) -> artifact_interface.CreateCatalogResponse:
        tags = tags if tags is not None else []

        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.CreateCatalog,
                request=artifact_interface.CreateCatalogRequest(
                    namespace_id=namespace_id,
                    name=name,
                    description=description,
                    tags=tags,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.CreateCatalog,
            request=artifact_interface.CreateCatalogRequest(
                namespace_id=namespace_id,
                name=name,
                description=description,
                tags=tags,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def list_catalogs(
        self,
        namespace_id: str,
        async_enabled: bool = False,
    ) -> artifact_interface.ListCatalogsResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.ListCatalogs,
                request=artifact_interface.ListCatalogsRequest(
                    namespace_id=namespace_id,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.ListCatalogs,
            request=artifact_interface.ListCatalogsRequest(
                namespace_id=namespace_id,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def update_catalog(
        self,
        catalog_id: str,
        description: str,
        namespace_id: str,
        tags: Optional[list[str]] = None,
        async_enabled: bool = False,
    ) -> artifact_interface.UpdateCatalogResponse:
        tags = tags if tags is not None else []

        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.UpdateCatalog,
                request=artifact_interface.UpdateCatalogRequest(
                    catalog_id=catalog_id,
                    description=description,
                    tags=tags,
                    namespace_id=namespace_id,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.UpdateCatalog,
            request=artifact_interface.UpdateCatalogRequest(
                catalog_id=catalog_id,
                description=description,
                tags=tags,
                namespace_id=namespace_id,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def delete_catalog(
        self,
        namespace_id: str,
        catalog_id: str,
        async_enabled: bool = False,
    ) -> artifact_interface.DeleteCatalogResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.DeleteCatalog,
                request=artifact_interface.DeleteCatalogRequest(
                    namespace_id=namespace_id,
                    catalog_id=catalog_id,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.DeleteCatalog,
            request=artifact_interface.DeleteCatalogRequest(
                namespace_id=namespace_id,
                catalog_id=catalog_id,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def upload_catalog_file(
        self,
        namespace_id: str,
        catalog_id: str,
        file_path: str,
        async_enabled: bool = False,
    ) -> artifact_interface.UploadCatalogFileResponse:
        file = process_file(file_path)

        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.UploadCatalogFile,
                request=artifact_interface.UploadCatalogFileRequest(
                    namespace_id=namespace_id,
                    catalog_id=catalog_id,
                    file=file,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.UploadCatalogFile,
            request=artifact_interface.UploadCatalogFileRequest(
                namespace_id=namespace_id,
                catalog_id=catalog_id,
                file=file,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def delete_catalog_file(
        self,
        file_uid: str,
        async_enabled: bool = False,
    ) -> artifact_interface.DeleteCatalogFileResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.DeleteCatalogFile,
                request=artifact_interface.DeleteCatalogFileRequest(
                    file_uid=file_uid,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.DeleteCatalogFile,
            request=artifact_interface.DeleteCatalogFileRequest(
                file_uid=file_uid,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def process_catalog_files(
        self,
        file_uids: list[str],
        async_enabled: bool = False,
    ) -> artifact_interface.ProcessCatalogFilesResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.ProcessCatalogFiles,
                request=artifact_interface.ProcessCatalogFilesRequest(
                    file_uids=file_uids,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.ProcessCatalogFiles,
            request=artifact_interface.ProcessCatalogFilesRequest(
                file_uids=file_uids,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def list_catalog_files(
        self,
        namespace_id: str,
        catalog_id: str,
        files_filter: Optional[list[str]] = None,
        page_size: int = 10,
        page_token: str = "",
        async_enabled: bool = False,
    ) -> artifact_interface.ListCatalogFilesResponse:
        list_catalog_files_filter = artifact_interface.ListCatalogFilesFilter()
        files_filter = files_filter if files_filter is not None else []
        for file_uid in files_filter:
            list_catalog_files_filter.file_uids.append(file_uid)

        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.ListCatalogFiles,
                request=artifact_interface.ListCatalogFilesRequest(
                    namespace_id=namespace_id,
                    catalog_id=catalog_id,
                    filter=list_catalog_files_filter,
                    page_size=page_size,
                    page_token=page_token,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.ListCatalogFiles,
            request=artifact_interface.ListCatalogFilesRequest(
                namespace_id=namespace_id,
                catalog_id=catalog_id,
                filter=list_catalog_files_filter,
                page_size=page_size,
                page_token=page_token,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def list_chunks(
        self,
        namespace_id: str,
        catalog_id: str,
        file_uid: str,
        async_enabled: bool = False,
    ) -> chunk_interface.ListChunksResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.ListChunks,
                request=chunk_interface.ListChunksRequest(
                    namespace_id=namespace_id,
                    catalog_id=catalog_id,
                    file_uid=file_uid,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.ListChunks,
            request=chunk_interface.ListChunksRequest(
                namespace_id=namespace_id,
                catalog_id=catalog_id,
                file_uid=file_uid,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def get_source_file(
        self,
        namespace_id: str,
        catalog_id: str,
        file_uid: str,
        async_enabled: bool = False,
    ) -> chunk_interface.GetSourceFileResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.GetSourceFile,
                request=chunk_interface.GetSourceFileRequest(
                    namespace_id=namespace_id,
                    catalog_id=catalog_id,
                    file_uid=file_uid,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.GetSourceFile,
            request=chunk_interface.GetSourceFileRequest(
                namespace_id=namespace_id,
                catalog_id=catalog_id,
                file_uid=file_uid,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def update_chunk(
        self,
        chunk_uid: str,
        retrievable: bool,
        async_enabled: bool = False,
    ) -> chunk_interface.UpdateChunkResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.UpdateChunk,
                request=chunk_interface.UpdateChunkRequest(
                    chunk_uid=chunk_uid,
                    retrievable=retrievable,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.UpdateChunk,
            request=chunk_interface.UpdateChunkRequest(
                chunk_uid=chunk_uid,
                retrievable=retrievable,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def similarity_chunks_search(
        self,
        namespace_id: str,
        catalog_id: str,
        text_prompt: str,
        top_k: int,
        async_enabled: bool = False,
    ) -> chunk_interface.SimilarityChunksSearchResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.SimilarityChunksSearch,
                request=chunk_interface.SimilarityChunksSearchRequest(
                    namespace_id=namespace_id,
                    catalog_id=catalog_id,
                    text_prompt=text_prompt,
                    top_k=top_k,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.SimilarityChunksSearch,
            request=chunk_interface.SimilarityChunksSearchRequest(
                namespace_id=namespace_id,
                catalog_id=catalog_id,
                text_prompt=text_prompt,
                top_k=top_k,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def question_answering(
        self,
        namespace_id: str,
        catalog_id: str,
        question: str,
        top_k: int,
        async_enabled: bool = False,
    ) -> qa_interface.QuestionAnsweringResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.QuestionAnswering,
                request=qa_interface.QuestionAnsweringRequest(
                    namespace_id=namespace_id,
                    catalog_id=catalog_id,
                    question=question,
                    top_k=top_k,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.QuestionAnswering,
            request=qa_interface.QuestionAnsweringRequest(
                namespace_id=namespace_id,
                catalog_id=catalog_id,
                question=question,
                top_k=top_k,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def get_file_catalog(
        self,
        namespace_id: str,
        catalog_id: str,
        file_id: str = "",
        file_uid: str = "",
        async_enabled: bool = False,
    ) -> file_catalog_interface.GetFileCatalogResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.GetFileCatalog,
                request=file_catalog_interface.GetFileCatalogRequest(
                    namespace_id=namespace_id,
                    catalog_id=catalog_id,
                    file_id=file_id,
                    file_uid=file_uid,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.GetFileCatalog,
            request=file_catalog_interface.GetFileCatalogRequest(
                namespace_id=namespace_id,
                catalog_id=catalog_id,
                file_id=file_id,
                file_uid=file_uid,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def get_object_upload_url(
        self,
        namespace_id: str,
        object_name: str,
        url_expire_days: int,
        last_modified_time: datetime,
        object_expire_days: int,
        async_enabled: bool = False,
    ) -> object_interface.GetObjectUploadURLResponse:
        timestamp = timestamp_pb2.Timestamp()
        timestamp.FromDatetime(last_modified_time)

        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.GetObjectUploadURL,
                request=object_interface.GetObjectUploadURLRequest(
                    namespace_id=namespace_id,
                    object_name=object_name,
                    url_expire_days=url_expire_days,
                    last_modified_time=timestamp,
                    object_expire_days=object_expire_days,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.GetObjectUploadURL,
            request=object_interface.GetObjectUploadURLRequest(
                namespace_id=namespace_id,
                object_name=object_name,
                url_expire_days=url_expire_days,
                last_modified_time=timestamp,
                object_expire_days=object_expire_days,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def get_object_download_url(
        self,
        namespace_id: str,
        object_uid: str,
        object_name: str,
        url_expire_days: int,
        async_enabled: bool = False,
    ) -> object_interface.GetObjectDownloadURLResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.GetObjectDownloadURL,
                request=object_interface.GetObjectDownloadURLRequest(
                    namespace_id=namespace_id,
                    object_uid=object_uid,
                    object_name=object_name,
                    url_expire_days=url_expire_days,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.GetObjectDownloadURL,
            request=object_interface.GetObjectDownloadURLRequest(
                namespace_id=namespace_id,
                object_uid=object_uid,
                object_name=object_name,
                url_expire_days=url_expire_days,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()
